@@ -131,8 +131,8 @@ AtomDefDlg::initialize()
   readSettings();
 
   // Validator stuff for the atom symbol lineedit.
-  QRegExp symbolRegExp("[A-Z][a-z]*");
-  QValidator *validator = new QRegExpValidator(symbolRegExp, this);
+  QRegularExpression symbolRegExp("[A-Z][a-z]*");
+  QValidator *validator = new QRegularExpressionValidator(symbolRegExp, this);
 
   m_ui.symbolLineEdit->setValidator(validator);
 
