@@ -174,7 +174,7 @@ CalculatorChemPadDlg::parseColumnCount(QString &line)
 QColor
 CalculatorChemPadDlg::parseColor(QString &line)
 {
-  QStringList list = line.split("%", QString::SkipEmptyParts);
+  QStringList list = line.split("%", Qt::SkipEmptyParts);
 
   // The first item of the list is "color", which we have to
   // remove.
@@ -199,7 +199,7 @@ CalculatorChemPadDlg::parseColor(QString &line)
 
   // The rgb specification is the second item in the list (index 1)
 
-  QStringList rgbList = list.at(1).split(",", QString::SkipEmptyParts);
+  QStringList rgbList = list.at(1).split(",", Qt::SkipEmptyParts);
 
   bool ok = false;
 
@@ -285,7 +285,7 @@ CalculatorChemPadDlg::parseSeparator(QString &line)
 
   QStringList list;
 
-  list = line.split("%", QString::SkipEmptyParts);
+  list = line.split("%", Qt::SkipEmptyParts);
 
   // The first item is the "chempadgroup" string.
   list.removeFirst();
@@ -314,7 +314,7 @@ CalculatorChemPadDlg::parseKey(QString &line, QStringList &list)
   CalculatorWnd *wnd    = static_cast<CalculatorWnd *>(parentWidget());
   ChemPadButton *button = 0;
 
-  list = line.split("%", QString::SkipEmptyParts);
+  list = line.split("%", Qt::SkipEmptyParts);
 
   // The first item of the list is "chempadkey", which we have to
   // remove.
@@ -376,7 +376,7 @@ CalculatorChemPadDlg::parseKey(QString &line, QStringList &list)
 
       // We are left with "bgHex,fgHex"
 
-      QStringList colorList = colorSpec.split(",", QString::SkipEmptyParts);
+      QStringList colorList = colorSpec.split(",", Qt::SkipEmptyParts);
       if(colorList.size() != 2)
         {
           qDebug() << __FILE__ << __LINE__
