@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +31,8 @@
  */
 
 
-#pragma once
-
-/////////////////////// stdlib includes
+#ifndef CALCULATOR_CHEM_PAD_DLG_HPP
+#define CALCULATOR_CHEM_PAD_DLG_HPP
 
 
 /////////////////////// Qt includes
@@ -45,48 +44,24 @@
 #include <QGridLayout>
 #include <QVBoxLayout>
 
-
-/////////////////////// pappsomspp includes
-
-
-/////////////////////// libXpertMass includes
-
-
-/////////////////////// libXpertMassGui includes
-
-
 /////////////////////// Local includes
-
+// #include "ui_CalculatorChemPadDlg.h"
 #include "ChemPadButton.hpp"
 #include "CalculatorChemPadGroupBox.hpp"
 
 
-namespace MsXpS
-{
-namespace MassXpert
+namespace msxps
 {
 
+	namespace massxpert
+	{
+
+
 
 class CalculatorChemPadDlg : public QDialog
 {
   Q_OBJECT
 
-  public:
-  CalculatorChemPadDlg(CalculatorWnd *parent);
-  ~CalculatorChemPadDlg();
-
-  bool parseFile(QString &);
-  bool setup(QString &, const QString & = QString());
-
-  bool parseColumnCount(QString &);
-  QColor parseColor(QString &);
-
-  QStringList parseSeparator(QString &);
-  ChemPadButton *parseKey(QString &, QStringList &);
-
-  public slots:
-  void close();
-
   private:
   //    Ui::CalculatorChemPadDlg m_ui;
 
@@ -104,14 +79,33 @@ class CalculatorChemPadDlg : public QDialog
 
   QHash<QString, QColor> m_colorHash;
 
-  int m_columnCount = 0;
-  int m_row         = 0;
-  int m_column      = 0;
+  int m_columnCount;
+  int m_row;
+  int m_column;
 
-  void keyPressEvent(QKeyEvent *event);
-  void keyReleaseEvent(QKeyEvent *event);
+  void keyPressEvent(QKeyEvent *);
+  void keyReleaseEvent(QKeyEvent *);
+
+  public:
+  CalculatorChemPadDlg(CalculatorWnd *parent);
+  ~CalculatorChemPadDlg();
+
+  bool parseFile(QString &);
+  bool setup(QString &, const QString & = QString());
+
+  bool parseColumnCount(QString &);
+  QColor parseColor(QString &);
+
+  QStringList parseSeparator(QString &);
+  ChemPadButton *parseKey(QString &, QStringList &);
+
+  public slots:
+  void close();
 };
 
+} // namespace massxpert
 
-} // namespace MassXpert
-} // namespace MsXpS
+} // namespace msxps
+
+
+#endif // CALCULATOR_CHEM_PAD_DLG_HPP
