@@ -1170,12 +1170,12 @@ CalculatorWnd::accountFormula(const QString &formula, int times)
       // re-reading the formula text (useful when entering complex
       // formula for saccharides, for example, in my own
       // experience).
-      text.remove(QRegExp("\\s+"));
+      text.remove(QRegularExpression("\\s+"));
 
       // Note that we might also have a title for the formula, which
       // is enclosed between `"' at the beginning of the line.
 
-      text.remove(QRegExp("\".*\""));
+      text.remove(QRegularExpression("\".*\""));
 
       // How many times should the formula be accounted for?
       count = m_ui.formulaSpinBox->value();
@@ -1473,12 +1473,12 @@ CalculatorWnd::simplifyFormula()
   // user might enter spaces in the formula to ease re-reading the
   // formula text (useful when entering complex formula for
   // saccharides, for example, in my own experience).
-  text.remove(QRegExp("\\s+"));
+  text.remove(QRegularExpression("\\s+"));
 
   // Note that we might also have a title for the formula, which is
   // enclosed between `"' at the beginning of the line.
 
-  text.remove(QRegExp("\".*\""));
+  text.remove(QRegularExpression("\".*\""));
 
   // Validate the formula by creating a fake modification object
   // with it and by accounting masses for that formula.
