@@ -155,7 +155,7 @@ CleavageDlg::initialize()
        "PPM: part per million"));
 
   filterAct = new QAction(tr("Toggle Filtering"), this);
-  filterAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_G));
+  filterAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_G));
   this->addAction(filterAct);
   connect(filterAct, SIGNAL(triggered()), this, SLOT(filterOptionsToggled()));
 
@@ -1035,7 +1035,7 @@ CleavageDlg::exportResultsFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   prepareResultsTxtString();
 
