@@ -281,7 +281,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainText(
             qFatal(
               "Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-          *output += text;
+          *output += *text;
           delete text;
         }
       else
@@ -292,7 +292,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainText(
             qFatal(
               "Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-          *output += text;
+          *output += *text;
           delete text;
         }
 
@@ -590,7 +590,7 @@ CleaveOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
     }
   else if(mouseEvent->buttons() & Qt::RightButton)
     {
-      contextMenu->popup(mouseEvent->globalPos());
+      contextMenu->popup(mouseEvent->globalPosition().toPoint());
       return;
     }
 
