@@ -102,7 +102,7 @@ CleaveOligomerTableViewSortProxyModel::lessThan(const QModelIndex &left,
   QVariant leftData  = sourceModel()->data(left);
   QVariant rightData = sourceModel()->data(right);
 
-  if(leftData.type() == QVariant::Int)
+  if(leftData.typeId() == QMetaType::Int)
     {
       // The Partial column
 
@@ -111,7 +111,7 @@ CleaveOligomerTableViewSortProxyModel::lessThan(const QModelIndex &left,
 
       return (leftValue < rightValue);
     }
-  if(leftData.type() == QVariant::Bool)
+  if(leftData.typeId() == QMetaType::Bool)
     {
       // The Modif column
 
@@ -120,7 +120,7 @@ CleaveOligomerTableViewSortProxyModel::lessThan(const QModelIndex &left,
 
       return (leftValue < rightValue);
     }
-  else if(leftData.type() == QVariant::String &&
+  else if(leftData.typeId() == QMetaType::QString &&
           (left.column() == CLEAVE_OLIGO_MONO_COLUMN ||
            left.column() == CLEAVE_OLIGO_AVG_COLUMN))
     {
@@ -144,7 +144,7 @@ CleaveOligomerTableViewSortProxyModel::lessThan(const QModelIndex &left,
       return (leftValue < rightValue);
     }
 
-  if(leftData.type() == QVariant::String)
+  if(leftData.typeId() == QMetaType::QString)
     {
       QString leftString  = leftData.toString();
       QString rightString = rightData.toString();
@@ -234,7 +234,7 @@ CleaveOligomerTableViewSortProxyModel::sortName(QString left,
   //
   QString local = left;
 
-  QStringList leftList = local.split("#", QString::SkipEmptyParts);
+  QStringList leftList = local.split("#", Qt::SkipEmptyParts);
 
   bool ok            = false;
   int leftPartialInt = leftList.at(0).toInt(&ok);
@@ -252,7 +252,7 @@ CleaveOligomerTableViewSortProxyModel::sortName(QString left,
   //
   local = right;
 
-  QStringList rightList = local.split("#", QString::SkipEmptyParts);
+  QStringList rightList = local.split("#", Qt::SkipEmptyParts);
 
   ok                  = false;
   int rightPartialInt = rightList.at(0).toInt(&ok);
