@@ -38,10 +38,9 @@
 /////////////////////// Local includes
 #include "AbstractPolChemDefDependentDlg.hpp"
 #include "ui_CleaveSpecDefDlg.h"
-#include <libXpertMass/PolChemDefEntity.hpp>
 
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -51,25 +50,36 @@ namespace MsXpS
 
 class PolChemDef;
 class PolChemDefWnd;
+class CleaveSpec;
+class CleaveRule;
 
 
 class CleaveSpecDefDlg : public AbstractPolChemDefDependentDlg
 {
   Q_OBJECT
 
+  private:
+  Ui::CleaveSpecDefDlg m_ui;
+
+  QList<CleaveSpec *> *mp_list;
+
+  void closeEvent(QCloseEvent *event);
+
+  void writeSettings();
+  void readSettings();
+
+
   public:
-  CleaveSpecDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
-                  PolChemDefWnd *polChemDefWnd,
-                  const QString &settingsFilePath,
-                  const QString &applicationName,
-                  const QString &description);
+  CleaveSpecDefDlg(PolChemDef *polChemDef,
+                   PolChemDefWnd *polChemDefWnd,
+                   const QString &settingsFilePath);
 
   ~CleaveSpecDefDlg();
 
   bool initialize();
 
-  void updateCleaveSpecIdentityDetails(libXpertMass::CleaveSpec *);
-  void updateCleaveRuleDetails(libXpertMass::CleaveRule *);
+  void updateCleaveSpecIdentityDetails(CleaveSpec *);
+  void updateCleaveRuleDetails(CleaveRule *);
 
   void clearAllDetails();
 
@@ -97,22 +107,11 @@ class CleaveSpecDefDlg : public AbstractPolChemDefDependentDlg
   // WIDGETRY
   void cleaveSpecListWidgetItemSelectionChanged();
   void cleaveRuleListWidgetItemSelectionChanged();
-
-  private:
-  Ui::CleaveSpecDefDlg m_ui;
-
-  QList<libXpertMass::CleaveSpec *> *mp_list;
-
-  void closeEvent(QCloseEvent *event);
-
-  void writeSettings();
-  void readSettings();
-
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // CLEAVE_SPEC_DEF_DLG_HPP
