@@ -66,21 +66,21 @@ CompositionTreeViewSortProxyModel::lessThan(const QModelIndex &left,
   QVariant leftData  = sourceModel()->data(left);
   QVariant rightData = sourceModel()->data(right);
 
-  if(leftData.type() == QVariant::Int)
+  if(leftData.typeId() == QMetaType::Int)
     {
       int leftValue  = leftData.toInt();
       int rightValue = rightData.toInt();
 
       return (leftValue < rightValue);
     }
-  if(leftData.type() == QVariant::Bool)
+  if(leftData.typeId() == QMetaType::Bool)
     {
       int leftValue  = leftData.toInt();
       int rightValue = rightData.toInt();
 
       return (leftValue < rightValue);
     }
-  else if(leftData.type() == QVariant::Double)
+  else if(leftData.typeId() == QMetaType::Double)
     {
       bool ok = false;
 
@@ -92,7 +92,7 @@ CompositionTreeViewSortProxyModel::lessThan(const QModelIndex &left,
       return (leftValue < rightValue);
     }
 
-  if(leftData.type() == QVariant::String)
+  if(leftData.typeId() == QMetaType::QString)
     {
       QString leftString  = leftData.toString();
       QString rightString = rightData.toString();
