@@ -655,7 +655,7 @@ CompositionsDlg::exportResultsFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   stream << *mpa_resultsString;
 
