@@ -326,7 +326,7 @@ FragmentOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
     }
   else if(mouseEvent->buttons() & Qt::RightButton)
     {
-      contextMenu->popup(mouseEvent->globalPos());
+      contextMenu->popup(mouseEvent->globalPosition().toPoint());
       return;
     }
 
