@@ -103,7 +103,7 @@ FragmentOligomerTableViewSortProxyModel::lessThan(
   QVariant leftData  = sourceModel()->data(left);
   QVariant rightData = sourceModel()->data(right);
 
-  if(leftData.type() == QVariant::Int)
+  if(leftData.typeId() == QMetaType::Int)
     {
       // The Partial column
 
@@ -112,7 +112,7 @@ FragmentOligomerTableViewSortProxyModel::lessThan(
 
       return (leftValue < rightValue);
     }
-  if(leftData.type() == QVariant::Bool)
+  if(leftData.typeId() == QMetaType::Bool)
     {
       // The Modif column
 
@@ -121,7 +121,7 @@ FragmentOligomerTableViewSortProxyModel::lessThan(
 
       return (leftValue < rightValue);
     }
-  else if(leftData.type() == QVariant::String &&
+  else if(leftData.typeId() == QMetaType::QString &&
           (left.column() == FRAGMENT_OLIGO_MONO_COLUMN ||
            left.column() == FRAGMENT_OLIGO_AVG_COLUMN))
     {
@@ -135,7 +135,7 @@ FragmentOligomerTableViewSortProxyModel::lessThan(
       return (leftValue < rightValue);
     }
 
-  if(leftData.type() == QVariant::String)
+  if(leftData.typeId() == QMetaType::QString)
     {
       QString leftString  = leftData.toString();
       QString rightString = rightData.toString();
@@ -226,7 +226,7 @@ FragmentOligomerTableViewSortProxyModel::sortName(QString left,
   //
   QString local = left;
 
-  QStringList leftList = local.split("#", QString::SkipEmptyParts);
+  QStringList leftList = local.split("#", Qt::SkipEmptyParts);
 
   // First item is necessarily <fragspecname>, second item is
   // nessarily <numb> and last item is necessarily z=<charge>.
@@ -253,7 +253,7 @@ FragmentOligomerTableViewSortProxyModel::sortName(QString left,
   //
   local = right;
 
-  QStringList rightList = local.split("#", QString::SkipEmptyParts);
+  QStringList rightList = local.split("#", Qt::SkipEmptyParts);
 
   // First item is necessarily <fragspecname>, second item is
   // nessarily <numb> and last item is necessarily z=<charge>.
