@@ -166,7 +166,7 @@ FragmentationDlg::initialize()
        "PPM: part per million"));
 
   filterAct = new QAction(tr("Toggle Filtering"), this);
-  filterAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_F));
+  filterAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_F));
   this->addAction(filterAct);
   connect(filterAct, SIGNAL(triggered()), this, SLOT(filterOptionsToggled()));
 
@@ -878,7 +878,7 @@ FragmentationDlg::exportResultsFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   prepareResultsTxtString();
 
