@@ -31,7 +31,8 @@
  */
 
 
-#pragma once
+#ifndef MAIN_WINDOW_HPP
+#define MAIN_WINDOW_HPP
 
 
 /////////////////////// Qt includes
@@ -44,8 +45,6 @@
 #include "AboutDlg.hpp"
 #include "../nongui/UserSpec.hpp"
 #include "../nongui/ConfigSettings.hpp"
-#include <libXpertMass/PolChemDef.hpp>
-#include <libXpertMass/PolChemDefSpec.hpp>
 
 
 class QAction;
@@ -53,7 +52,7 @@ class QMenu;
 class QTextEdit;
 
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -62,59 +61,14 @@ namespace MsXpS
 
 
 class SequenceEditorWnd;
+class PolChemDefSpec;
+class PolChemDef;
 
 
 class MainWindow : public QMainWindow
 {
   Q_OBJECT
 
-  public:
-  MainWindow(const QString &moduleName);
-  ~MainWindow();
-
-  QString configSettingsFilePath() const;
-  const UserSpec &userSpec() const;
-  const ConfigSettings *configSettings() const;
-
-  bool setConfigSettingsManually();
-
-  void initializeDecimalPlacesOptions();
-
-  void setLastFocusedSeqEdWnd(SequenceEditorWnd *);
-
-  QList<libXpertMass::PolChemDefSpec *> *polChemDefCatList();
-  libXpertMass::PolChemDefSpec *polChemDefSpecName(const QString &);
-  libXpertMass::PolChemDefSpec *polChemDefSpecFilePath(const QString &);
-
-  void polChemDefCatStringList(QStringList &stringList);
-
-  std::vector<libXpertMass::PolChemDefCstSPtr> polChemDefList();
-  libXpertMass::PolChemDefCstSPtr polChemDefByName(const QString &name);
-
-  bool isSequenceEditorWnd(SequenceEditorWnd *) const;
-
-  public slots:
-  void openPolChemDef();
-  void newPolChemDef();
-
-  void newCalculator();
-
-  void openSequence(const QString &fileName = QString());
-  void openSampleSequence();
-  void newSequence();
-  void delistSequenceEditorWnd(SequenceEditorWnd *wnd);
-
-  void mzLab();
-
-  void about();
-	void showAboutDlg();
-
-  void massListSorter();
-  void seqTools();
-
-  protected:
-  void closeEvent(QCloseEvent *);
-
   private:
   QString m_moduleName;
 
@@ -134,11 +88,11 @@ class MainWindow : public QMainWindow
   // List of all the polymer chemistry definition specifications that
   // were created during parsing of all the different catalogue files
   // on the system.
-  QList<libXpertMass::PolChemDefSpec *> m_polChemDefCatList;
+  QList<PolChemDefSpec *> m_polChemDefCatList;
 
   // List of all the polymer chemistry definitions that are loaded in
   // memory and usable to load polymer sequences.
-  std::vector<libXpertMass::PolChemDefCstSPtr> m_polChemDefList;
+  QList<PolChemDef *> m_polChemDefList;
 
   QMenu *fileMenu;
 
@@ -182,10 +136,56 @@ class MainWindow : public QMainWindow
   bool initializeUserConfig();
 
 
+  public slots:
+  void openPolChemDef();
+  void newPolChemDef();
+
+  void newCalculator();
+
+  void openSequence(const QString &fileName = QString());
+  void openSampleSequence();
+  void newSequence();
+  void delistSequenceEditorWnd(SequenceEditorWnd *wnd);
+
+  void mzLab();
+
+  void about();
+	void showAboutDlg();
+
+  void massListSorter();
+  void seqTools();
+
+  protected:
+  void closeEvent(QCloseEvent *);
+
+  public:
+  MainWindow(const QString &moduleName);
+  ~MainWindow();
+
+  QString configSettingsFilePath() const;
+  const UserSpec &userSpec() const;
+  const ConfigSettings *configSettings() const;
+
+  bool setConfigSettingsManually();
+
+  void initializeDecimalPlacesOptions();
+
+  void setLastFocusedSeqEdWnd(SequenceEditorWnd *);
+
+  QList<PolChemDefSpec *> *polChemDefCatList();
+  QList<PolChemDef *> *polChemDefList();
+
+  void polChemDefCatStringList(QStringList &stringList);
+  PolChemDefSpec *polChemDefSpecName(const QString &);
+  PolChemDefSpec *polChemDefSpecFilePath(const QString &);
+  PolChemDef *polChemDefName(const QString &);
+
+  bool isSequenceEditorWnd(SequenceEditorWnd *) const;
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
+#endif /* MAIN_WINDOW_HPP */
