@@ -195,7 +195,7 @@ MassSearchDlg::initialize()
   m_ui.avgFilterToleranceLineEdit->setText("1");
 
   monoFilterAct = new QAction(tr("Toggle Mono Filtering"), this);
-  monoFilterAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M, Qt::Key_F));
+  monoFilterAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M, Qt::CTRL | Qt::Key_F));
   this->addAction(monoFilterAct);
   connect(
     monoFilterAct, SIGNAL(triggered()), this, SLOT(monoFilterOptionsToggled()));
@@ -203,7 +203,7 @@ MassSearchDlg::initialize()
   m_ui.monoFilteringOptionsGroupBox->addAction(monoFilterAct);
 
   avgFilterAct = new QAction(tr("Toggle Avg Filtering"), this);
-  avgFilterAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_A, Qt::Key_F));
+  avgFilterAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_A, Qt::CTRL | Qt::Key_F));
   this->addAction(avgFilterAct);
   connect(
     avgFilterAct, SIGNAL(triggered()), this, SLOT(avgFilterOptionsToggled()));
@@ -547,7 +547,7 @@ MassSearchDlg::parseMassText(int type)
   else
     Q_ASSERT(0);
 
-  QStringList splitList = text.split(QRegExp("\\s+"), QString::SkipEmptyParts);
+  QStringList splitList = text.split(QRegularExpression("\\s+"), Qt::SkipEmptyParts);
 
   for(int iter = 0; iter < splitList.size(); ++iter)
     {
@@ -1599,7 +1599,7 @@ MassSearchDlg::exportResultsFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   prepareResultsTxtString();
 
