@@ -354,7 +354,7 @@ MassSearchOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
     }
   else if(mouseEvent->buttons() & Qt::RightButton)
     {
-      contextMenu->popup(mouseEvent->globalPos());
+      contextMenu->popup(mouseEvent->globalPosition().toPoint());
       return;
     }
 
