@@ -78,7 +78,7 @@ MassSearchOligomerTableViewMimeData::formats() const
 
 QVariant
 MassSearchOligomerTableViewMimeData::retrieveData(
-  const QString &format, QVariant::Type preferredType) const
+  const QString &format, QMetaType preferredType) const
 {
   if(format == "text/plain")
     {
