@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,30 +30,28 @@
  * END software license
  */
 
-/////////////////////// libXpertMass includes
-#include <MsXpS/libXpertMassCore/Oligomer.hpp>
-#include <MsXpS/libXpertMassCore/Prop.hpp>
-
 
 /////////////////////// Local includes
 #include "MassSearchOligomerTableViewModel.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
+
+
 
 
 MassSearchOligomerTableViewModel::MassSearchOligomerTableViewModel(
-  libXpertMassCore::OligomerCollection *oligomerList, QObject *parent)
+  OligomerList *oligomerList, QObject *parent)
   : QAbstractTableModel(parent)
 {
   if(!oligomerList)
     qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
-  mp_oligomers = oligomerList;
+  mp_oligomerList = oligomerList;
 
   if(!parent)
     qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
@@ -70,10 +68,10 @@ MassSearchOligomerTableViewModel::~MassSearchOligomerTableViewModel()
 }
 
 
-const libXpertMassCore::OligomerCollection *
+const OligomerList *
 MassSearchOligomerTableViewModel::oligomerList()
 {
-  return mp_oligomers;
+  return mp_oligomerList;
 }
 
 
@@ -107,7 +105,7 @@ MassSearchOligomerTableViewModel::rowCount(const QModelIndex &parent) const
 {
   Q_UNUSED(parent);
 
-  return mp_oligomers->size();
+  return mp_oligomerList->size();
 }
 
 
@@ -182,8 +180,7 @@ MassSearchOligomerTableViewModel::data(const QModelIndex &index, int role) const
       // row. Let's find the row first, so that we get to the proper
       // oligomer.
 
-      libXpertMassCore::OligomerSPtr oligomer_sp =
-        mp_oligomers->getOligomersCstRef().at(row);
+      Oligomer *oligomer = mp_oligomerList->at(row);
 
       // Now see what's the column that is asked for. Prepare a
       // string that we'll feed with the right data before returning
@@ -196,64 +193,48 @@ MassSearchOligomerTableViewModel::data(const QModelIndex &index, int role) const
           // The searched m/z value is stored in a Prop. Get it
           // right away.
 
-          libXpertMassCore::Prop *prop = oligomer_sp->prop("SEARCHED_MZ");
-
+          Prop *prop = oligomer->prop("SEARCHED_MZ");
           Q_ASSERT(prop);
 
           double value = 0;
 
           value = *static_cast<const double *>(prop->data());
-          valueString.setNum(value, 'f', libXpertMassCore::OLIGOMER_DEC_PLACES);
+          valueString.setNum(value, 'f', OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_NAME_COLUMN)
         {
-          valueString = oligomer_sp->getName();
+          valueString = oligomer->name();
         }
       else if(column == MASS_SEARCH_OLIGO_COORDINATES_COLUMN)
         {
-          libXpertMassCore::IndexRange *index_range_p =
-            oligomer_sp->getCalcOptionsCstRef()
-              .getIndexRangeCollectionCstRef()
-              .mostInclusiveLeftRightIndexRange();
-
           valueString = QString("[%1-%2]")
-                          .arg(index_range_p->m_start + 1)
-                          .arg(index_range_p->m_stop + 1);
-
-          delete(index_range_p);
+                          .arg(oligomer->startIndex() + 1)
+                          .arg(oligomer->endIndex() + 1);
         }
       else if(column == MASS_SEARCH_OLIGO_ERROR_COLUMN)
         {
           // The error m/z value is stored in a Prop. Get it right
           // away.
 
-          libXpertMassCore::DoubleProp *prop =
-            static_cast<libXpertMassCore::DoubleProp *>(
-              oligomer_sp->prop("ERROR_MZ"));
+          Prop *prop = oligomer->prop("ERROR_MZ");
           Q_ASSERT(prop);
 
           double value = 0;
 
           value = *static_cast<const double *>(prop->data());
-          valueString.setNum(value, 'f', libXpertMassCore::OLIGOMER_DEC_PLACES);
+          valueString.setNum(value, 'f', OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_MONO_COLUMN)
         {
-          valueString = QString::number(
-            oligomer_sp->getMass(libXpertMassCore::Enums::MassType::MONO),
-            'f',
-            libXpertMassCore::OLIGOMER_DEC_PLACES);
+          valueString = oligomer->monoString(OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_AVG_COLUMN)
         {
-          valueString = QString::number(
-            oligomer_sp->getMass(libXpertMassCore::Enums::MassType::AVG),
-            'f',
-            libXpertMassCore::OLIGOMER_DEC_PLACES);
+          valueString = oligomer->avgString(OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_MODIF_COLUMN)
         {
-          if(oligomer_sp->isModified())
+          if(oligomer->isModified())
             valueString = "True";
           else
             valueString = "False";
@@ -273,11 +254,10 @@ MassSearchOligomerTableViewModel::data(const QModelIndex &index, int role) const
 
 
 int
-MassSearchOligomerTableViewModel::addOligomer(
-  libXpertMassCore::Oligomer *oligomer_p)
+MassSearchOligomerTableViewModel::addOligomer(Oligomer *oligomer)
 {
-  if(!oligomer_p)
-    qFatal() << "Programming error.";
+  if(!oligomer)
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
   // We receive an oligomer which we are asked to add to the list of
   // oligomers that we actually do not own, since they are owned by
@@ -288,38 +268,44 @@ MassSearchOligomerTableViewModel::addOligomer(
   // addition work here.
 
   // Note that we are acutally *transferring* the oligomer to this
-  // model's mp_oligomers.
+  // model's mp_oligomerList.
 
-  int existing_oligomers_count = mp_oligomers->size();
+  int oligomerCount = mp_oligomerList->size();
 
   // qDebug() << __FILE__ << __LINE__
   //          << "model oligomers:" << oligomerCount;
 
-  int oligomers_to_add_count = 1;
+  int oligomersToAdd = 1;
 
   // qDebug() << __FILE__ << __LINE__
   //          << "oligomers to add:" << oligomersToAdd;
 
+  int addedOligomerCount = 0;
+
   // We have to let know the model that we are going to modify the
   // list of oligomers and thus the number of rows in the table
   // view. We will append the oligomer to the preexisting ones,
   // which means we are going to have our appended oligomer at
   // index=oligomerCount.
 
-  beginInsertRows(QModelIndex(),
-                  existing_oligomers_count,
-                  (existing_oligomers_count + oligomers_to_add_count - 1));
-  // FIXME check that this works flawlessly
-  mp_oligomers->getOligomersRef().emplace_back(oligomer_p);
+  beginInsertRows(
+    QModelIndex(), oligomerCount, (oligomerCount + oligomersToAdd - 1));
+
+  for(int iter = 0; iter < oligomersToAdd; ++iter)
+    {
+      mp_oligomerList->append(oligomer);
+
+      ++addedOligomerCount;
+    }
+
   endInsertRows();
 
-  return 1 /*the single oligomer added*/;
+  return addedOligomerCount;
 }
 
 
 int
-MassSearchOligomerTableViewModel::addOligomers(
-  const libXpertMassCore::OligomerCollection &oligomer_collection)
+MassSearchOligomerTableViewModel::addOligomers(const OligomerList &oligomerList)
 {
   // We receive a list of oligomers which we are asked to add to the
   // list of oligomers that we actually do not own, since they are
@@ -330,19 +316,19 @@ MassSearchOligomerTableViewModel::addOligomers(
   // addition work here.
 
   // Note that we are acutally *transferring* all the oligomers from
-  // the oligomerList to this model's mp_oligomers.
+  // the oligomerList to this model's mp_oligomerList.
 
-  int existing_oligomers_count = mp_oligomers->size();
+  int oligomerCount = mp_oligomerList->size();
 
   // qDebug() << __FILE__ << __LINE__
   //          << "model oligomers:" << oligomerCount;
 
-  int oligomers_to_add = oligomer_collection.size();
+  int oligomersToAdd = oligomerList.size();
 
   // qDebug() << __FILE__ << __LINE__
   //          << "oligomers to add:" << oligomersToAdd;
 
-  int added_oligomers_count = 0;
+  int addedOligomerCount = 0;
 
   // We have to let know the model that we are going to modify the
   // list of oligomers and thus the number of rows in the table
@@ -350,30 +336,32 @@ MassSearchOligomerTableViewModel::addOligomers(
   // which means we are going to have our first appended oligomer at
   // index = oligomerCount.
 
-  beginInsertRows(QModelIndex(),
-                  existing_oligomers_count,
-                  (existing_oligomers_count + oligomers_to_add - 1));
+  beginInsertRows(
+    QModelIndex(), oligomerCount, (oligomerCount + oligomersToAdd - 1));
 
-  for(libXpertMassCore::OligomerSPtr oligomer_sp :
-      oligomer_collection.getOligomersCstRef())
+  for(int iter = 0; iter < oligomersToAdd; ++iter)
     {
-      mp_oligomers->getOligomersRef().push_back(oligomer_sp);
-      ++added_oligomers_count;
+      Oligomer *oligomer = oligomerList.at(iter);
+
+      mp_oligomerList->append(oligomer);
+
+      ++addedOligomerCount;
     }
 
   endInsertRows();
 
-  return added_oligomers_count;
+  return addedOligomerCount;
 }
 
 
 int
-MassSearchOligomerTableViewModel::removeOligomers(std::size_t start_index,
-                                                  std::size_t stop_index)
+MassSearchOligomerTableViewModel::removeOligomers(int firstIndex, int lastIndex)
 {
   // We are asked to remove the oligomers [firstIndex--lastIndex].
 
-  // firstIndex has to be >= 0 and < mp_oligomers->size().
+  // firstIndex has to be >= 0 and < mp_oligomerList->size(). If
+  // lastIndex is -1, then remove all oligomers in range
+  // [firstIndex--last oligomer].
 
   // We are asked to remove the oligomers from the list of oligomers
   // that we actually do not own, since they are owned by the
@@ -383,36 +371,63 @@ MassSearchOligomerTableViewModel::removeOligomers(std::size_t start_index,
   // that the tableView takes them into account, we have to do that
   // removal work here.
 
-  std::size_t existing_oligomers_count = mp_oligomers->size();
+  int oligomerCount = mp_oligomerList->size();
 
-  qDebug() << "There are" << existing_oligomers_count << "oligomers.";
-
-  if(!existing_oligomers_count)
+  if(!oligomerCount)
     return 0;
 
-  if(start_index >= existing_oligomers_count)
-    qFatal() << "Programming error. Out of bounds error.";
+  if(firstIndex < 0 || firstIndex >= oligomerCount)
+    {
+      // qDebug() << __FILE__ << __LINE__
+      //          << "firstIndex:" << firstIndex
+      //          << "lastIndex:" << lastIndex;
 
-  if(stop_index >= existing_oligomers_count)
-    qFatal() << "Programming error. Out of bounds error.";
+      qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
+    }
 
-  qDebug() << "start_index:" << start_index << "stop_index:" << stop_index;
+  int firstIdx = firstIndex;
 
-  beginRemoveRows(QModelIndex(), start_index, stop_index);
+  // lastIndex can be < 0 (that is -1) if the oligomer to remove
+  // must go up to the last oligomer in the list.
+  if(lastIndex < -1 || lastIndex >= oligomerCount)
+    {
+      // qDebug() << __FILE__ << __LINE__
+      //          << "firstIndex:" << firstIndex
+      //          << "lastIndex:" << lastIndex;
 
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_start_iterator =
-    mp_oligomers->getOligomersRef().begin() + start_index;
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_stop_iterator =
-    mp_oligomers->getOligomersRef().begin() + stop_index + 1;
+      qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
+    }
 
-  mp_oligomers->getOligomersRef().erase(the_start_iterator, the_stop_iterator);
+  int lastIdx = 0;
+
+  if(lastIndex == -1)
+    lastIdx = (oligomerCount - 1);
+  else
+    lastIdx = lastIndex;
+
+  beginRemoveRows(QModelIndex(), firstIdx, lastIdx);
+
+  int removedOligomerCount = 0;
+
+  int iter = lastIdx;
+
+  while(iter >= firstIdx)
+    {
+      Oligomer *oligomer = mp_oligomerList->takeAt(iter);
+
+      delete oligomer;
+
+      ++removedOligomerCount;
+
+      --iter;
+    }
 
   endRemoveRows();
 
-  return existing_oligomers_count - mp_oligomers->getOligomersRef().size();
+  return removedOligomerCount;
 }
 
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
