@@ -271,7 +271,7 @@ MonomerCrossLinkDlg::populateCrossLinkList(bool all)
       // position 3(that is index 2).
 
       QStringList stringList =
-        text.split('/', QString::SkipEmptyParts, Qt::CaseSensitive);
+        text.split('/', Qt::SkipEmptyParts, Qt::CaseSensitive);
 
       //      qDebug() << __FILE__ << __LINE__
       // 		<< "stringList:" << stringList.at(0) << stringList.at(1);
@@ -448,7 +448,7 @@ MonomerCrossLinkDlg::crossLinkedMonomerListWidgetItemActivated(
   // representation is 136958312.
 
   QStringList stringList =
-    text.split('/', QString::SkipEmptyParts, Qt::CaseSensitive);
+    text.split('/', Qt::SkipEmptyParts, Qt::CaseSensitive);
 
   // The crossLink(quintptr) pointer is the second string in the list.
   bool ok                = false;
@@ -544,7 +544,7 @@ MonomerCrossLinkDlg::crossLinkListWidgetItemSelectionChanged()
   // which the integer representation is 136958312.
 
   QStringList stringList =
-    text.split('/', QString::SkipEmptyParts, Qt::CaseSensitive);
+    text.split('/', Qt::SkipEmptyParts, Qt::CaseSensitive);
 
   // The crossLink(quintptr) pointer is the third string in the list.
   bool ok                = false;
@@ -621,7 +621,7 @@ MonomerCrossLinkDlg::crossLinkListWidgetItemActivated(QListWidgetItem *item)
   // which the integer representation is 136958312.
 
   QStringList stringList =
-    text.split('/', QString::SkipEmptyParts, Qt::CaseSensitive);
+    text.split('/', Qt::SkipEmptyParts, Qt::CaseSensitive);
 
   // The crossLink(quintptr) pointer is the third string in the list.
   bool ok                = false;
@@ -686,9 +686,9 @@ MonomerCrossLinkDlg::parseTargetMonomerString(
   QString text = m_ui.targetPositionLineEdit->text();
 
   // Unspacify text.
-  text.remove(QRegExp("\\s+"));
+  text.remove(QRegularExpression("\\s+"));
 
-  QStringList positionList = text.split(";", QString::SkipEmptyParts);
+  QStringList positionList = text.split(";", Qt::SkipEmptyParts);
 
   if(!positionList.size())
     return false;
@@ -966,7 +966,7 @@ MonomerCrossLinkDlg::uncrossLink()
   // which the integer representation is 136958312.
 
   QStringList stringList =
-    text.split('/', QString::SkipEmptyParts, Qt::CaseSensitive);
+    text.split('/', Qt::SkipEmptyParts, Qt::CaseSensitive);
 
   // The crossLink(quintptr) pointer is the third string in the list.
   bool ok                = false;
