@@ -136,8 +136,8 @@ MonomerDefDlg::initialize()
   QString regExp =
     QString("[A-Z][a-z]{0,%1}").arg(mp_polChemDef->codeLength() - 1);
 
-  QRegExp codeRegExp(regExp);
-  QValidator *validator = new QRegExpValidator(codeRegExp, this);
+  QRegularExpression codeRegExp(regExp);
+  QValidator *validator = new QRegularExpressionValidator(codeRegExp, this);
 
   m_ui.codeLineEdit->setValidator(validator);
 
@@ -520,8 +520,8 @@ MonomerDefDlg::codeLengthSpinBoxValueChanged(int value)
   QString regExp = QString("[A-Z][a-z]{0,%1}").arg(value - 1);
   //    qDebug() << "new regExp:" << regExp;
 
-  QRegExp codeRegExp(regExp);
-  QValidator *validator = new QRegExpValidator(codeRegExp, this);
+  QRegularExpression codeRegExp(regExp);
+  QValidator *validator = new QRegularExpressionValidator(codeRegExp, this);
 
   m_ui.codeLineEdit->setValidator(validator);
 
