@@ -773,7 +773,7 @@ MzCalculationDlg::exportResultsFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   prepareResultsTxtString();
 
