@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,9 @@
  * END software license
  */
 
-#pragma once
 
-/////////////////////// stdlib includes
+#ifndef MZ_CALCULATION_DLG_HPP
+#define MZ_CALCULATION_DLG_HPP
 
 
 /////////////////////// Qt includes
@@ -40,28 +40,20 @@
 #include <QSortFilterProxyModel>
 
 
-/////////////////////// pappsomspp includes
-
-
-/////////////////////// libXpertMass includes
-#include <MsXpS/libXpertMassCore/PolChemDef.hpp>
-#include <MsXpS/libXpertMassCore/Ionizer.hpp>
-#include <MsXpS/libXpertMassCore/OligomerCollection.hpp>
-
-
-/////////////////////// libXpertMassGui includes
-
-
 /////////////////////// Local includes
-#include "../nongui/globals.hpp"
 #include "ui_MzCalculationDlg.h"
+#include "../nongui/PolChemDef.hpp"
+#include "MzCalculationTreeViewModel.hpp"
 #include "MzCalculationTreeViewSortProxyModel.hpp"
+#include "../nongui/Ionizable.hpp"
+#include "../nongui/OligomerList.hpp"
 
+namespace msxps
+{
+
+	namespace massxpert
+	{
 
-namespace MsXpS
-{
-namespace MassXpert
-{
 
 
 class MzCalculationTreeViewModel;
@@ -72,13 +64,38 @@ class MzCalculationDlg : public QDialog
 {
   Q_OBJECT
 
+  private:
+  Ui::MzCalculationDlg m_ui;
+
+  // The results-exporting strings. ////////////////////////////////
+  QString *mpa_resultsString;
+  QString m_resultsFilePath;
+  //////////////////////////////////// The results-exporting strings.
+
+  QString m_configSettingsFilePath;
+
+  const PolChemDef *mp_polChemDef;
+
+  const QList<Atom *> &m_atomList;
+
+  OligomerList m_oligomerList;
+
+  Formula m_formula;
+
+  IonizeRule m_ionizeRule;
+
+  QList<Ionizable *> m_ionizableList;
+
+  MzCalculationTreeViewModel *mpa_mzTreeViewModel;
+  MzCalculationTreeViewSortProxyModel *mpa_mzProxyModel;
+
+  void closeEvent(QCloseEvent *event);
+
   public:
-  MzCalculationDlg(QWidget *parent,
-                   const QString &config_settings_file_path,
-                   const libXpertMassCore::PolChemDefCstSPtr pol_chem_def_csp,
-                   const QString &application_name,
-                   const QString &description,
-                   const libXpertMassCore::Ionizer &ionizer,
+  MzCalculationDlg(QWidget *,
+                   const QString &configSettingsFilePath,
+                   const PolChemDef *,
+                   const IonizeRule *,
                    double = 0,
                    double = 0);
 
@@ -86,10 +103,13 @@ class MzCalculationDlg : public QDialog
 
   void setupTreeView();
 
-  bool getSrcIonizerData(libXpertMassCore::Ionizer &ionizer);
-  bool getDestIonizerData(libXpertMassCore::Ionizer &ionizer);
+  bool getSrcIonizeRuleData(IonizeRule *);
+  bool getDestIonizeRuleData(IonizeRule *);
 
-  double getSourceMass(libXpertMassCore::Enums::MassType mass_type, bool &ok);
+  Ponderable *getSourcePonderable();
+
+  void freeIonizableList();
+  void emptyIonizableList();
 
   // The results-exporting functions. ////////////////////////////////
   void prepareResultsTxtString();
@@ -103,31 +123,11 @@ class MzCalculationDlg : public QDialog
   void calculate();
   void formulaCheckBoxToggled(bool);
   void exportResults(int);
-
-  protected:
-  Ui::MzCalculationDlg m_ui;
-
-  // The results-exporting strings. ////////////////////////////////
-  QString m_resultsString;
-  QString m_resultsFilePath;
-  //////////////////////////////////// The results-exporting strings.
-
-  QString m_configSettingsFilePath;
-
-  libXpertMassCore::PolChemDefCstSPtr mcsp_polChemDef;
-
-  libXpertMassCore::Formula m_formula;
-
-  libXpertMassCore::Ionizer m_ionizer;
-
-  std::vector<IonSPtr> m_ions;
-
-  MzCalculationTreeViewModel *mpa_mzTreeViewModel;
-  MzCalculationTreeViewSortProxyModel *mpa_mzProxyModel;
-
-  void closeEvent(QCloseEvent *event);
 };
 
+} // namespace massxpert
 
-} // namespace MassXpert
-} // namespace MsXpS
+} // namespace msxps
+
+
+#endif // MZ_CALCULATION_DLG_HPP
