@@ -66,7 +66,7 @@ MzCalculationTreeViewSortProxyModel::lessThan(const QModelIndex &left,
   QVariant leftData  = sourceModel()->data(left);
   QVariant rightData = sourceModel()->data(right);
 
-  if(leftData.type() == QVariant::Int)
+  if(leftData.typeId() == QMetaType::Int)
     {
       // The Partial column
 
@@ -75,7 +75,7 @@ MzCalculationTreeViewSortProxyModel::lessThan(const QModelIndex &left,
 
       return (leftValue < rightValue);
     }
-  if(leftData.type() == QVariant::Bool)
+  if(leftData.typeId() == QMetaType::Bool)
     {
       // The Modif column
 
@@ -84,7 +84,7 @@ MzCalculationTreeViewSortProxyModel::lessThan(const QModelIndex &left,
 
       return (leftValue < rightValue);
     }
-  else if(leftData.type() == QVariant::Double)
+  else if(leftData.typeId() == QMetaType::Double)
     {
       bool ok = false;
 
@@ -96,7 +96,7 @@ MzCalculationTreeViewSortProxyModel::lessThan(const QModelIndex &left,
       return (leftValue < rightValue);
     }
 
-  if(leftData.type() == QVariant::String)
+  if(leftData.typeId() == QMetaType::QString)
     {
       QString leftString  = leftData.toString();
       QString rightString = rightData.toString();
