@@ -35,25 +35,21 @@
 #include <QMessageBox>
 #include <QCloseEvent>
 #include <QDebug>
-#include <QSettings>
-
-
-/////////////////////// libmass includes
-#include <libXpertMass/PolChemDefEntity.hpp>
-#include <libXpertMass/IonizeRule.hpp>
 
 
 /////////////////////// Local includes
 #include "MzLabFormulaBasedActionsDlg.hpp"
 #include "MzLabInputOligomerTableViewDlg.hpp"
 #include "MzLabWnd.hpp"
+#include "../nongui/IonizeRule.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
+
 
 
 MzLabFormulaBasedActionsDlg::MzLabFormulaBasedActionsDlg(
@@ -70,10 +66,9 @@ MzLabFormulaBasedActionsDlg::MzLabFormulaBasedActionsDlg(
 
   m_ui.incrementChargeSpinBox->setRange(-1000000000, 1000000000);
 
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
-  libXpertMass::IonizeRule ionizeRule = polChemDefCstSPtr->ionizeRule();
+  IonizeRule ionizeRule = polChemDef->ionizeRule();
 
   m_ui.reIonizationFormulaLineEdit->setText(ionizeRule.formula());
   m_ui.reIonizationChargeSpinBox->setValue(ionizeRule.charge());
@@ -148,15 +143,11 @@ MzLabFormulaBasedActionsDlg::applyFormulaPushButton()
   // definition in use in this mzLab, because we need to validate
   // the formula.
 
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
-  libXpertMass::Formula formula(text);
+  Formula formula(text);
 
-  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
-    polChemDefCstSPtr->getIsotopicDataCstSPtr();
-
-  if(!formula.validate(isotopic_data_csp))
+  if(!formula.validate(polChemDef->atomList()))
     {
       QMessageBox::warning(this,
                            tr("massXpert: mz Lab"),
@@ -164,7 +155,7 @@ MzLabFormulaBasedActionsDlg::applyFormulaPushButton()
                               "The formula '%3' is not valid.")
                              .arg(__FILE__)
                              .arg(__LINE__)
-                             .arg(formula.toString()));
+                             .arg(formula.text()));
       return;
     }
 
@@ -252,7 +243,7 @@ MzLabFormulaBasedActionsDlg::reionizePushButton()
   // pointer to that dialog window. But first, check if the threshold
   // entered in the line edit is empty/correct or not.
 
-  libXpertMass::IonizeRule ionizeRule;
+  IonizeRule ionizeRule;
 
   ionizeRule.setFormula(m_ui.reIonizationFormulaLineEdit->text());
   ionizeRule.setCharge(m_ui.reIonizationChargeSpinBox->value());
@@ -262,13 +253,9 @@ MzLabFormulaBasedActionsDlg::reionizePushButton()
   // definition in use in this mzLab, because we need to validate
   // the ionization rule.
 
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
-  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
-    polChemDefCstSPtr->getIsotopicDataCstSPtr();
-
-  if(!ionizeRule.validate(isotopic_data_csp))
+  if(!ionizeRule.validate(polChemDef->atomList()))
     {
       QMessageBox::warning(this,
                            tr("massXpert: mz Lab"),
@@ -309,4 +296,4 @@ MzLabFormulaBasedActionsDlg::reionizePushButton()
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
