@@ -477,7 +477,7 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
 
   // First, split the text file into lines.
   QStringList stringList =
-    text.split("\n", QString::SkipEmptyParts, Qt::CaseSensitive);
+    text.split("\n", Qt::SkipEmptyParts, Qt::CaseSensitive);
   // qDebug() << __FILE__ << __LINE__
   //          << "stringList:" << stringList;
 
@@ -498,7 +498,7 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
       // qDebug() << __FILE__ << __LINE__
       //          << "text:" << text;
 
-      QStringList stringList = text.split(delimiter, QString::SkipEmptyParts);
+      QStringList stringList = text.split(delimiter, Qt::SkipEmptyParts);
 
       // qDebug() << __FILE__ << __LINE__
       //          << "stringList:" << stringList;
