@@ -41,10 +41,10 @@
 
 /////////////////////// Local includes
 #include "ui_MzLabMassBasedActionsDlg.h"
-#include <libXpertMass/globals.hpp>
+#include "../nongui/globals.hpp"
 #include "MzLabWnd.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -77,7 +77,7 @@ class MzLabMassBasedActionsDlg : public QDialog
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
