@@ -46,7 +46,7 @@
 #include "MzLabInputOligomerTableViewModel.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -71,9 +71,9 @@ class MzLabOutputOligomerTableViewDlg : public QDialog
   // we are given ownership on them, and are thus responsible for
   // freeing them. Hence, the mpa_prefix that indicated "allocated
   // here" ownership -> free that stuff when non more needed.
-  QList<OligomerPairSPtr> *mpa_oligomerPairList;
+  QList<OligomerPair *> *mpa_oligomerPairList;
 
-  libXpertMass::MassType m_massType;
+  MassType m_massType;
 
   // The dialog windows that hold the data that were used to perform
   // the matches that we are reporting in *this dialog window.
@@ -93,8 +93,8 @@ class MzLabOutputOligomerTableViewDlg : public QDialog
 
   public:
   MzLabOutputOligomerTableViewDlg(QWidget *,
-                                  QList<OligomerPairSPtr> *,
-                                  libXpertMass::MassType,
+                                  QList<OligomerPair *> *,
+                                  MassType,
                                   MzLabInputOligomerTableViewDlg *,
                                   MzLabInputOligomerTableViewDlg *,
                                   const QString & = QString(),
@@ -112,7 +112,7 @@ class MzLabOutputOligomerTableViewDlg : public QDialog
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_OUTPUT_OLIGOMER_TABLE_VIEW_DLG_HPP
