@@ -41,15 +41,16 @@
 #include "../nongui/globals.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
+
 
 
 MzLabOutputOligomerTableViewModel::MzLabOutputOligomerTableViewModel(
-  QList<OligomerPairSPtr> *oligomerPairList, QObject *parent)
+  QList<OligomerPair *> *oligomerPairList, QObject *parent)
   : QAbstractTableModel(parent)
 {
   QList<QVariant> rootData;
@@ -178,10 +179,9 @@ MzLabOutputOligomerTableViewModel::headerData(int section,
 
 
 bool
-MzLabOutputOligomerTableViewModel::setData(
-  const QModelIndex &index,
-  [[maybe_unused]] const QVariant &value,
-  [[maybe_unused]] int role)
+MzLabOutputOligomerTableViewModel::setData(const QModelIndex &index,
+                                           [[maybe_unused]] const QVariant &value,
+                                           [[maybe_unused]] int role)
 {
   // Fixme. Is it correct to not call anything here ?
 
@@ -211,7 +211,7 @@ MzLabOutputOligomerTableViewModel::data(const QModelIndex &index,
       // row. Let's find the row first, so that we get to the proper
       // oligomerPair.
 
-      OligomerPairSPtr oligomer_pair_sp = mp_oligomerPairList->at(row);
+      OligomerPair *oligomerPair = mp_oligomerPairList->at(row);
 
       // Now see what's the column that is asked for. Prepare a
       // string that we'll feed with the right data before returning
@@ -222,34 +222,34 @@ MzLabOutputOligomerTableViewModel::data(const QModelIndex &index,
       if(column == MZ_LAB_OUTPUT_OLIGO_1_MASS_COLUMN)
         {
           valueString.setNum(
-            oligomer_pair_sp->mass1(), 'f', libXpertMass::OLIGOMER_DEC_PLACES);
+            oligomerPair->mass1(), 'f', OLIGOMER_DEC_PLACES);
         }
       else if(column == MZ_LAB_OUTPUT_OLIGO_1_CHARGE_COLUMN)
         {
-          int charge = oligomer_pair_sp->charge1();
+          int charge = oligomerPair->charge1();
 
           valueString.setNum(charge);
         }
       else if(column == MZ_LAB_OUTPUT_OLIGO_2_MASS_COLUMN)
         {
           valueString.setNum(
-            oligomer_pair_sp->mass2(), 'f', libXpertMass::OLIGOMER_DEC_PLACES);
+            oligomerPair->mass2(), 'f', OLIGOMER_DEC_PLACES);
         }
       else if(column == MZ_LAB_OUTPUT_OLIGO_2_CHARGE_COLUMN)
         {
-          int charge = oligomer_pair_sp->charge2();
+          int charge = oligomerPair->charge2();
 
           valueString.setNum(charge);
         }
       else if(column == MZ_LAB_OUTPUT_OLIGO_ERROR_COLUMN)
         {
           valueString.setNum(
-            oligomer_pair_sp->error(), 'f', libXpertMass::OLIGOMER_DEC_PLACES);
+            oligomerPair->error(), 'f', OLIGOMER_DEC_PLACES);
         }
       else if(column == MZ_LAB_OUTPUT_OLIGO_MATCH_COLUMN)
         {
           valueString =
-            (oligomer_pair_sp->isMatching() ? QString("1") : QString("0"));
+            (oligomerPair->isMatching() ? QString("1") : QString("0"));
         }
       else
         {
@@ -266,13 +266,12 @@ MzLabOutputOligomerTableViewModel::data(const QModelIndex &index,
 
 
 void
-MzLabOutputOligomerTableViewModel::addOligomerPair(
-  OligomerPairSPtr oligomer_pair_sp)
+MzLabOutputOligomerTableViewModel::addOligomerPair(OligomerPair *oligomerPair)
 {
-  if(!oligomer_pair_sp)
+  if(!oligomerPair)
     qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
-  // We receive an oligomer_pair_sp which we are asked to add to the
+  // We receive an oligomerPair which we are asked to add to the
   // list of oligomer pairs that we actually do not own, since they
   // are owned by the parent dialog window instance that is the
   // "owner" of this model. But since we want to add the oligomer
@@ -307,20 +306,17 @@ MzLabOutputOligomerTableViewModel::addOligomerPair(
 
   for(int iter = 0; iter < oligomerPairsToAdd; ++iter)
     {
-      mp_oligomerPairList->append(oligomer_pair_sp);
+      mp_oligomerPairList->append(oligomerPair);
 
       ++addedOligomerPairCount;
     }
 
   endInsertRows();
 
-  if(oligomerPairsToAdd != ++addedOligomerPairCount)
-    qFatal("Programming error.");
-
   return;
 }
 
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
