@@ -36,11 +36,10 @@
 #include <QtGlobal>
 #include <QMessageBox>
 #include <QInputDialog>
-#include <libXpertMass/PolChemDefEntity.hpp>
 
 /////////////////////// Local includes
 #include "MzLabWnd.hpp"
-#include "ProgramWindow.hpp"
+#include "MainWindow.hpp"
 #include "MzLabInputOligomerTableViewDlg.hpp"
 #include "MzLabOutputOligomerTableViewDlg.hpp"
 #include "MzLabFormulaBasedActionsDlg.hpp"
@@ -48,45 +47,37 @@
 #include "MzLabMatchBasedActionsDlg.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-MzLabWnd::MzLabWnd(ProgramWindow *parent,
-                   const QString &polChemDefFilePath,
-                   const QString &applicationName,
-                   const QString &description)
-  : AbstractMainTaskWindow{parent, "MzLabWnd", applicationName, description}
+
+MzLabWnd::MzLabWnd(MainWindow *parent, const QString &polChemDefFilePath)
+  : AbstractMainTaskWindow{parent, "MzLabWnd", "massXpert: m/z lab"}
 {
   m_forciblyClose = false;
 
   if(polChemDefFilePath.isEmpty())
     {
-      QMessageBox::warning(
-        0,
-        QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription),
-        tr("Polymer chemistry definition filepath empty."),
-        QMessageBox::Ok);
+      QMessageBox::warning(0,
+                           tr("massXpert - mz Lab"),
+                           tr("Polymer chemistry definition filepath empty."),
+                           QMessageBox::Ok);
 
       return;
     }
 
-  // Start by creating the polymer chemistry definition.
-
-  msp_polChemDef = std::make_shared<libXpertMass::PolChemDef>();
-
-  msp_polChemDef->setXmlDataFilePath(polChemDefFilePath);
+  m_polChemDef.setFilePath(polChemDefFilePath);
 
   if(!initialize())
     {
-      QMessageBox::warning(
-        0,
-        QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription),
-        tr("Failed to initialize the mz lab window."),
-        QMessageBox::Ok);
+      QMessageBox::warning(0,
+                           tr("massXpert - mz Lab"),
+                           tr("Failed to initialize the mz lab window."),
+                           QMessageBox::Ok);
     }
 }
 
@@ -153,17 +144,8 @@ MzLabWnd::initialize()
   setAttribute(Qt::WA_DeleteOnClose);
   statusBar()->setSizeGripEnabled(true);
 
-  // qDebug() << "PolChemDef: " << msp_polChemDef->filePath();
-
-  // Craft the base name of the full file path
-  // so that we can inform the user in the title bar of the window.
-  QString file_name =
-    QFileInfo(msp_polChemDef->getXmlDataFilePath()).baseName();
-
-  setWindowTitle(QString("%1 - %2 %3[*]")
-                   .arg(m_applicationName)
-                   .arg(m_windowDescription)
-                   .arg(file_name));
+  setWindowTitle(
+    tr("%1 %2[*]").arg(tr("massXpert: mz Lab - ")).arg(m_polChemDef.name()));
 
   readSettings();
 
@@ -224,13 +206,13 @@ MzLabWnd::initialize()
           SLOT(matchBasedActionsPushButton()));
 
 
-  if(!libXpertMass::PolChemDef::renderXmlPolChemDefFile(msp_polChemDef))
+  if(!m_polChemDef.renderXmlPolChemDefFile())
     return false;
 
   m_ui.ionizationChargeSpinBox->setRange(1, 1000000000);
   m_ui.ionizationLevelSpinBox->setRange(0, 1000000000);
 
-  m_ionizeRule = msp_polChemDef->ionizeRule();
+  m_ionizeRule = m_polChemDef.ionizeRule();
 
   m_ui.ionizationFormulaLineEdit->setText(m_ionizeRule.formula());
   m_ui.ionizationChargeSpinBox->setValue(m_ionizeRule.charge());
@@ -242,21 +224,14 @@ MzLabWnd::initialize()
 }
 
 
-libXpertMass::PolChemDefCstSPtr
-MzLabWnd::polChemDefCstSPtr()
+PolChemDef *
+MzLabWnd::polChemDef()
 {
-  return msp_polChemDef;
+  return &m_polChemDef;
 }
 
 
-libXpertMass::PolChemDefSPtr
-MzLabWnd::polChemDefSPtr()
-{
-  return msp_polChemDef;
-}
-
-
-const libXpertMass::IonizeRule &
+const IonizeRule &
 MzLabWnd::ionizeRule() const
 {
   return m_ionizeRule;
@@ -266,10 +241,8 @@ MzLabWnd::ionizeRule() const
 void
 MzLabWnd::updateWindowTitle()
 {
-  setWindowTitle(QString("%1 - %2 %3[*]")
-                   .arg(m_applicationName)
-                   .arg(m_windowDescription)
-                   .arg(msp_polChemDef->name()));
+  setWindowTitle(
+    tr("%1 %2[*]").arg(tr("massXpert: mz Lab - ")).arg(m_polChemDef.name()));
 }
 
 
@@ -289,21 +262,17 @@ MzLabWnd::ionizationLevelChanged(int value)
 void
 MzLabWnd::ionizationFormulaChanged(const QString &text)
 {
-  libXpertMass::Formula formula(text);
+  Formula formula(text);
 
-  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
-    msp_polChemDef->getIsotopicDataCstSPtr();
-
-  if(!formula.validate(isotopic_data_csp))
+  if(!formula.validate(m_polChemDef.atomList()))
     {
-      QMessageBox::warning(
-        this,
-        QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription),
-        tr("%1@%2\n"
-           "The formula '%3' is not valid.")
-          .arg(__FILE__)
-          .arg(__LINE__)
-          .arg(formula.toString()));
+      QMessageBox::warning(this,
+                           tr("massXpert: mz Lab"),
+                           tr("%1@%2\n"
+                              "The formula '%3' is not valid.")
+                             .arg(__FILE__)
+                             .arg(__LINE__)
+                             .arg(formula.text()));
 
       m_ui.ionizationFormulaLineEdit->setText("");
 
@@ -433,11 +402,11 @@ MzLabWnd::inPlaceCalculation()
 MzLabInputOligomerTableViewDlg *
 MzLabWnd::newInputList()
 {
-  return newInputList(QString(), libXpertMass::MassType::MASS_NONE);
+  return newInputList(QString(), MassType::MASS_NONE);
 }
 
 MzLabInputOligomerTableViewDlg *
-MzLabWnd::newInputList(QString name, libXpertMass::MassType massType)
+MzLabWnd::newInputList(QString name, MassType massType)
 {
   // Ask that the user give a name to the list.
 
@@ -478,15 +447,14 @@ MzLabWnd::newInputList(QString name, libXpertMass::MassType massType)
   // Make sure the name is not already taken.
   if(findDlg(localName))
     {
-      QMessageBox::warning(
-        this,
-        QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription),
-        tr("%1@%2\n"
-           "The '%3' name is already taken.")
-          .arg(__FILE__)
-          .arg(__LINE__)
-          .arg(localName),
-        QMessageBox::Ok);
+      QMessageBox::warning(this,
+                           tr("massXpert: mz Lab"),
+                           tr("%1@%2\n"
+                              "The '%3' name is already taken.")
+                             .arg(__FILE__)
+                             .arg(__LINE__)
+                             .arg(localName),
+                           QMessageBox::Ok);
       return 0;
     }
 
@@ -612,12 +580,11 @@ MzLabWnd::maybeSave()
   if(isWindowModified())
     {
       QMessageBox::StandardButton ret;
-      ret = QMessageBox::warning(
-        this,
-        QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription),
-        tr("The mz Lab has been modified.\n"
-           "OK to exit?"),
-        QMessageBox::Yes | QMessageBox::No);
+      ret = QMessageBox::warning(this,
+                                 tr("massXpert - mz Lab"),
+                                 tr("The mz Lab has been modified.\n"
+                                    "OK to exit?"),
+                                 QMessageBox::Yes | QMessageBox::No);
 
       if(ret == QMessageBox::Yes)
         return true;
@@ -631,4 +598,4 @@ MzLabWnd::maybeSave()
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
