@@ -471,7 +471,7 @@ PkaPhPiDlg::exportResultsFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   stream << *mpa_resultsString;
 
