@@ -216,7 +216,7 @@ SeqToolsDlg::loadDictionary()
           continue;
         }
 
-      QStringList stringList = line.split(">", QString::SkipEmptyParts);
+      QStringList stringList = line.split(">", Qt::SkipEmptyParts);
 
       if(stringList.size() != 2)
         {
@@ -235,7 +235,7 @@ SeqToolsDlg::loadDictionary()
       else if(stringList.last().endsWith('\n'))
         stringList.last().chop(1);
 
-      if(stringList.first().contains(QRegExp("[0-9]")))
+      if(stringList.first().contains(QRegularExpression("[0-9]")))
         {
           bool ok           = false;
           m_inputCodeLength = stringList.first().toInt(&ok, 10);
