@@ -1925,7 +1925,7 @@ namespace massxpert
         // m_mouseDragging = true;
       }
 
-    if(event->buttons() & Qt::MidButton)
+    if(event->buttons() & Qt::MiddleButton)
       {
         mpa_selection->deselectRegions();
 
