@@ -397,7 +397,7 @@ SequenceEditorWnd::exportFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   prepareResultsTxtString();
 
@@ -464,21 +464,21 @@ SequenceEditorWnd::createActions()
   // File/ExportClipboard
   exportClipboardAct = new QAction(tr("Export to &clipboard"), this);
   exportClipboardAct->setShortcut(
-    QKeySequence(Qt::CTRL + Qt::Key_E, Qt::Key_C));
+    QKeySequence(Qt::CTRL | Qt::Key_E, Qt::CTRL | Qt::Key_C));
   exportClipboardAct->setStatusTip(tr("Export as text to the clipboard"));
   connect(
     exportClipboardAct, SIGNAL(triggered()), this, SLOT(exportClipboard()));
 
   // File/ExportFile
   exportFileAct = new QAction(tr("Export to &file"), this);
-  exportFileAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_E, Qt::Key_F));
+  exportFileAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_E, Qt::CTRL | Qt::Key_F));
   exportFileAct->setStatusTip(tr("Export as text to file"));
   connect(exportFileAct, SIGNAL(triggered()), this, SLOT(exportFile()));
 
   // File/ExportSelectFile
   exportSelectFileAct = new QAction(tr("&Select export file"), this);
   exportSelectFileAct->setShortcut(
-    QKeySequence(Qt::CTRL + Qt::Key_E, Qt::Key_S));
+    QKeySequence(Qt::CTRL | Qt::Key_E, Qt::CTRL | Qt::Key_S));
   exportSelectFileAct->setStatusTip(tr("Select file to export as text to"));
   connect(
     exportSelectFileAct, SIGNAL(triggered()), this, SLOT(exportSelectFile()));
@@ -519,13 +519,13 @@ SequenceEditorWnd::createActions()
 
   // Chemistry/ModifyMonomer
   modifMonomerAct = new QAction(tr("Modify &monomer(s)"), this);
-  modifMonomerAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M, Qt::Key_M));
+  modifMonomerAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M, Qt::CTRL | Qt::Key_M));
   modifMonomerAct->setStatusTip(tr("Modifies monomer(s)"));
   connect(modifMonomerAct, SIGNAL(triggered()), this, SLOT(modifMonomer()));
 
   // Chemistry/ModifyPolymer
   modifPolymerAct = new QAction(tr("Modify &polymer"), this);
-  modifPolymerAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M, Qt::Key_P));
+  modifPolymerAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M, Qt::CTRL | Qt::Key_P));
   modifPolymerAct->setStatusTip(tr("Modifies the polymer"));
   connect(modifPolymerAct, SIGNAL(triggered()), this, SLOT(modifPolymer()));
 
@@ -543,50 +543,50 @@ SequenceEditorWnd::createActions()
   // Chemistry/CrossLinkMonomer
   crossLinkMonomersAct = new QAction(tr("Cross-&link monomers"), this);
   crossLinkMonomersAct->setShortcut(
-    QKeySequence(Qt::CTRL + Qt::Key_L, Qt::Key_M));
+    QKeySequence(Qt::CTRL | Qt::Key_L, Qt::CTRL | Qt::Key_M));
   crossLinkMonomersAct->setStatusTip(tr("Cross-link monomers"));
   connect(
     crossLinkMonomersAct, SIGNAL(triggered()), this, SLOT(crossLinkMonomers()));
 
   // Chemistry/Cleave
   cleaveAct = new QAction(tr("&Cleave"), this);
-  cleaveAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_K));
+  cleaveAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_K));
   cleaveAct->setStatusTip(tr("Cleaves the polymer"));
   connect(cleaveAct, SIGNAL(triggered()), this, SLOT(cleave()));
 
   // Chemistry/Fragment
   fragmentAct = new QAction(tr("Fra&gment"), this);
-  fragmentAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_G));
+  fragmentAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_G));
   fragmentAct->setStatusTip(tr("Fragments the polymer"));
   connect(fragmentAct, SIGNAL(triggered()), this, SLOT(fragment()));
 
   // Chemistry/MassSearch
   massSearchAct = new QAction(tr("Search &masses"), this);
-  massSearchAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M, Qt::Key_S));
+  massSearchAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M, Qt::CTRL | Qt::Key_S));
   massSearchAct->setStatusTip(tr("Search oligomers based on mass"));
   connect(massSearchAct, SIGNAL(triggered()), this, SLOT(massSearch()));
 
   // Chemistry/mzCalculation
   mzCalculationAct = new QAction(tr("Compute m/z &ratios"), this);
-  mzCalculationAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M, Qt::Key_Z));
+  mzCalculationAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M, Qt::CTRL | Qt::Key_Z));
   mzCalculationAct->setStatusTip(tr("Compute ion charge families"));
   connect(mzCalculationAct, SIGNAL(triggered()), this, SLOT(mzCalculation()));
 
   // Chemistry/compositions
   compositionsAct = new QAction(tr("Determine compositions"), this);
-  compositionsAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_D, Qt::Key_C));
+  compositionsAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_D, Qt::CTRL | Qt::Key_C));
   compositionsAct->setStatusTip(tr("Determine compositions"));
   connect(compositionsAct, SIGNAL(triggered()), this, SLOT(compositions()));
 
   // Chemistry/isoelectricPoint
   pkaPhPiAct = new QAction(tr("pKa pH pI"), this);
-  pkaPhPiAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_P));
+  pkaPhPiAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_P));
   pkaPhPiAct->setStatusTip(tr("pKa pH pI"));
   connect(pkaPhPiAct, SIGNAL(triggered()), this, SLOT(pkaPhPi()));
 
   // Options/decimalPlaces
   decimalPlacesOptionsAct = new QAction(tr("Decimal places"), this);
-  decimalPlacesOptionsAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_D));
+  decimalPlacesOptionsAct->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_D));
   decimalPlacesOptionsAct->setStatusTip(tr("Decimal places"));
   connect(decimalPlacesOptionsAct,
           SIGNAL(triggered()),
@@ -2167,14 +2167,14 @@ SequenceEditorWnd::importPdbProt()
   // 3-letters long in the form of GLY.  "MET LEU THR GLN LYS THR
   // LYS ASP ILE VAL LYS ALA THR $");
 
-  QRegExp regExp(
+  QRegularExpression regExp(
     "^SEQRES "
     "[0-9 ][0-9 ][0-9 ] "
     "[A-Z ] "
     "[0-9 ][0-9 ][0-9 ][0-9 ]  "
     "([A-Z][A-Z][A-Z] ){1,13}[ ]*$");
 
-  QRegExpValidator validator(regExp, 0);
+  QRegularExpressionValidator validator(regExp, 0);
   int pos = 0;
 
   QChar currentId;
@@ -2259,9 +2259,9 @@ SequenceEditorWnd::importPdbProt()
       // "TYR TYR ILE CYS GLY PRO ILE PRO PHE MET ARG MET GLN"
 
       int firstResidueIndex =
-        tempSeq.indexOf(QRegExp("([A-Z][A-Z][A-Z] ){1,13}[ ]*$"), 0);
+        tempSeq.indexOf(QRegularExpression("([A-Z][A-Z][A-Z] ){1,13}[ ]*$"), 0);
 
-      int lastResidueIndex = tempSeq.lastIndexOf(QRegExp("[A-Z][A-Z][A-Z]"));
+      int lastResidueIndex = tempSeq.lastIndexOf(QRegularExpression("[A-Z][A-Z][A-Z]"));
 
       int stringLength = lastResidueIndex - firstResidueIndex;
 
