@@ -31,86 +31,58 @@
  */
 
 
-#pragma once
+#ifndef CLEAVE_OLIGOMER_HPP
+#define CLEAVE_OLIGOMER_HPP
 
 
 /////////////////////// Local includes
-#include <libXpertMass/Oligomer.hpp>
+#include "Oligomer.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
+	namespace massxpert
+	{
+
+
+
+class CleaveOligomer : public Oligomer
 {
-
-
-class CleaveOligomer : public libXpertMass::Oligomer
-{
-
-  friend class Cleaver;
+  protected:
+  int m_partialCleavage;
 
   public:
-  CleaveOligomer(libXpertMass::Polymer *,
+  CleaveOligomer(Polymer *,
                  const QString &name,
                  const QString &description,
                  bool modified,
-                 const libXpertMass::Ponderable &  = libXpertMass::Ponderable(),
-                 int startIndex               = -1,
-                 int endIndex                 = -1,
-                 libXpertMass::Formula             = libXpertMass::Formula(),
-                 int partialCleavage          = 0,
-                 const libXpertMass::CalcOptions & = libXpertMass::CalcOptions());
+                 const Ponderable &  = Ponderable(),
+                 int startIndex      = -1,
+                 int endIndex        = -1,
+                 int partialCleavage = 0,
+                 const CalcOptions & = CalcOptions());
 
-  CleaveOligomer(libXpertMass::Polymer *,
+  CleaveOligomer(Polymer *,
                  const QString &name,
                  const QString &description,
                  bool modified,
-                 const libXpertMass::Ponderable &  = libXpertMass::Ponderable(),
-                 int startIndex               = -1,
-                 int endIndex                 = -1,
-                 int partialCleavage          = 0,
-                 const libXpertMass::CalcOptions & = libXpertMass::CalcOptions());
-
-  CleaveOligomer(libXpertMass::Polymer *polymer,
-                 const QString &name,
-                 const QString &description,
-                 bool modified,
-                 const Ponderable &ponderable,
-                 const libXpertMass::IonizeRule &ionizeRule,
-                 const libXpertMass::CalcOptions &calcOptions,
-                 bool isIonized,
-                 int startIndex,
-                 int endIndex,
-                 int partialCleavage);
-
-  CleaveOligomer(libXpertMass::Polymer *,
-                 const QString &name,
-                 const QString &description,
-                 bool modified,
-                 double mono                  = 0,
-                 double avg                   = 0,
-                 int startIndex               = -1,
-                 int endIndex                 = -1,
-                 int partialCleavage          = 0,
-                 const libXpertMass::CalcOptions & = libXpertMass::CalcOptions());
+                 double mono         = 0,
+                 double avg          = 0,
+                 int startIndex      = -1,
+                 int endIndex        = -1,
+                 int partialCleavage = 0,
+                 const CalcOptions & = CalcOptions());
 
   CleaveOligomer(const CleaveOligomer &);
 
   void setPartialCleavage(int);
   int partialCleavage() const;
-
-  virtual QString elementalComposition() override;
-
-  protected:
-  libXpertMass::Formula m_formula;
-  int m_partialCleavage;
 };
 
-typedef std::shared_ptr<CleaveOligomer> CleaveOligomerSPtr;
-typedef std::shared_ptr<const CleaveOligomer> CleaveOligomerCstSPtr;
-
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
+
+#endif // CLEAVE_OLIGOMER_HPP
