@@ -31,49 +31,43 @@
  */
 
 
-/////////////////////// libmass includes
-#include <libXpertMass/Oligomer.hpp>
-#include <libXpertMass/PolChemDef.hpp>
-#include <libXpertMass/PolChemDefEntity.hpp>
-
-
 /////////////////////// Local includes
 #include "Cleaver.hpp"
 
 
-
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-Cleaver::Cleaver(libXpertMass::Polymer *polymer,
-                 const libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
+
+Cleaver::Cleaver(Polymer *polymer,
+                 const PolChemDef *polChemDef,
                  const CleaveOptions &cleaveOptions,
-                 const libXpertMass::CalcOptions &calcOptions,
-                 const libXpertMass::IonizeRule &ionizeRule)
+                 const CalcOptions &calcOptions,
+                 const IonizeRule &ionizeRule)
   : mp_polymer(polymer),
-    mcsp_polChemDef(polChemDefCstSPtr),
+    mp_polChemDef(polChemDef),
     m_cleaveOptions(cleaveOptions),
     m_calcOptions(calcOptions),
     m_ionizeRule(ionizeRule)
 {
-  Q_ASSERT(mp_polymer && mcsp_polChemDef);
-  mp_oligomerList = nullptr;
+  Q_ASSERT(mp_polymer && mp_polChemDef);
+  mp_oligomerList = 0;
 }
 
 
 Cleaver::Cleaver(const Cleaver &other)
   : mp_polymer(other.mp_polymer),
-    mcsp_polChemDef(other.mcsp_polChemDef),
+    mp_polChemDef(other.mp_polChemDef),
     m_cleaveOptions(other.m_cleaveOptions),
     m_calcOptions(other.m_calcOptions),
     m_ionizeRule(other.m_ionizeRule)
 {
-  Q_ASSERT(mp_polymer && mcsp_polChemDef);
-  mp_oligomerList = nullptr;
+  Q_ASSERT(mp_polymer && mp_polChemDef);
+  mp_oligomerList = 0;
 }
 
 
@@ -122,7 +116,8 @@ Cleaver::cleave(bool reset)
     {
       if(!m_cleaveOptions.parse())
         {
-          qDebug() << "Failed to parse the cleavage options";
+          qDebug() << __FILE__ << __LINE__
+                   << "Failed to parse the cleavage options";
 
           return false;
         }
@@ -134,7 +129,8 @@ Cleaver::cleave(bool reset)
 
   if(!fillIndexLists())
     {
-      qDebug() << "Index lists(cleave/nocleave) are empty."
+      qDebug() << __FILE__ << __LINE__
+               << "Index lists(cleave/nocleave) are empty."
                   "No oligomer generated.";
 
       // We can return true, as no error condition was found but not
@@ -145,7 +141,8 @@ Cleaver::cleave(bool reset)
 
   if(resolveCleavageNoCleavage() == -1)
     {
-      qDebug() << "Failed to resolve cleavage/nocleavage";
+      qDebug() << __FILE__ << __LINE__
+               << "Failed to resolve cleavage/nocleavage";
 
       return false;
     }
@@ -168,7 +165,8 @@ Cleaver::cleave(bool reset)
     {
       if(cleavePartial(iter) == -1)
         {
-          qDebug() << "Failed to perform partial cleavage at index:" << iter;
+          qDebug() << __FILE__ << __LINE__
+                   << "Failed to perform partial cleavage at index:" << iter;
 
           return false;
         }
@@ -190,7 +188,7 @@ Cleaver::cleave(bool reset)
 int
 Cleaver::fillIndexLists()
 {
-  QList<libXpertMass::CleaveMotif *> *motifList = m_cleaveOptions.motifList();
+  QList<CleaveMotif *> *motifList = m_cleaveOptions.motifList();
 
   while(m_cleaveIndexList.size())
     m_cleaveIndexList.removeFirst();
@@ -198,18 +196,19 @@ Cleaver::fillIndexLists()
   while(m_noCleaveIndexList.size())
     m_noCleaveIndexList.removeFirst();
 
-  // The cleavage might be performed on a selected portion of a sequence only,
-  // not necessarily on the whole polymer sequence.
+  // Since version 2.3.0, the cleavage might be performed on a
+  // selected portion of a sequence only, not necessarily on the
+  // whole polymer sequence.
 
-  libXpertMass::CoordinateList coordinateList = m_calcOptions.coordinateList();
-  libXpertMass::Coordinates *coordinates      = coordinateList.first();
+  CoordinateList coordinateList = m_calcOptions.coordinateList();
+  Coordinates *coordinates      = coordinateList.first();
 
   int startIndex = coordinates->start();
   int endIndex   = coordinates->end();
 
   for(int iter = 0; iter < motifList->size(); ++iter)
     {
-      libXpertMass::CleaveMotif *cleaveMotif = motifList->at(iter);
+      CleaveMotif *cleaveMotif = motifList->at(iter);
       Q_ASSERT(cleaveMotif);
 
       int index = startIndex - 1;
@@ -316,16 +315,14 @@ Cleaver::removeDuplicatesCleavage()
 
 
 int
-Cleaver::findCleaveMotif(libXpertMass::CleaveMotif &cleaveMotif,
-                         int startIndex,
-                         int endIndex)
+Cleaver::findCleaveMotif(CleaveMotif &cleaveMotif, int startIndex, int endIndex)
 {
   bool noGood = false;
 
   int firstIndex = 0;
 
-  QList<const libXpertMass::Monomer *> monomerList = mp_polymer->monomerList();
-  const QStringList &codeList                 = cleaveMotif.codeList();
+  QList<const Monomer *> monomerList = mp_polymer->monomerList();
+  const QStringList &codeList        = cleaveMotif.codeList();
 
 
   // We have to iterate in the polymer sequence starting at 'index', in
@@ -372,7 +369,7 @@ Cleaver::findCleaveMotif(libXpertMass::CleaveMotif &cleaveMotif,
 
   while(iterIndex < endIndex)
     {
-      const libXpertMass::Monomer *monomer = monomerList.at(iterIndex);
+      const Monomer *monomer = monomerList.at(iterIndex);
 
       if(monomer->code() != firstCode)
         {
@@ -436,38 +433,36 @@ Cleaver::findCleaveMotif(libXpertMass::CleaveMotif &cleaveMotif,
 
 
 bool
-Cleaver::accountCleaveRule(libXpertMass::CleaveRule *cleaveRule,
-                           CleaveOligomer *oligomer)
+Cleaver::accountCleaveRule(CleaveRule *cleaveRule, CleaveOligomer *oligomer)
 {
   Q_ASSERT(cleaveRule);
   Q_ASSERT(oligomer);
 
-  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
-    oligomer->polymer()->getPolChemDefCstSPtr()->getIsotopicDataCstSPtr();
+  const QList<Atom *> &refList =
+    oligomer->polymer()->polChemDef()->atomList();
 
-  // For each libXpertMass::Coordinates element in the oligomer, we have to ensure
+  // For each Coordinates element in the oligomer, we have to ensure
   // we apply the formula(s) that is/are required.
 
-  int coordinatesCount =
-    static_cast<libXpertMass::CoordinateList *>(oligomer)->size();
+  int coordinatesCount = static_cast<CoordinateList *>(oligomer)->size();
 
   //     qDebug() << __FILE__ << __LINE__
   // 	      << "Coordinates count:" << coordinatesCount;
 
   for(int iter = 0; iter < coordinatesCount; ++iter)
     {
-      libXpertMass::Coordinates *coordinates =
-        static_cast<libXpertMass::CoordinateList *>(oligomer)->at(iter);
+      Coordinates *coordinates =
+        static_cast<CoordinateList *>(oligomer)->at(iter);
 
       if(!cleaveRule->leftCode().isEmpty())
         {
           // The formula has to be there.
 
-          libXpertMass::Formula ruleFormula = cleaveRule->leftFormula();
-          Q_ASSERT(!ruleFormula.toString().isEmpty());
+          Formula ruleFormula = cleaveRule->leftFormula();
+          Q_ASSERT(!ruleFormula.text().isEmpty());
 
           // What is the monomer at the left end of current oligomer ?
-          const libXpertMass::Monomer &monomer = oligomer->atLeftEnd();
+          const Monomer &monomer = oligomer->atLeftEnd();
 
           if(monomer.code() == cleaveRule->leftCode())
             {
@@ -485,11 +480,8 @@ Cleaver::accountCleaveRule(libXpertMass::CleaveRule *cleaveRule,
                   // The monomer is not the left-end monomer, so the
                   // match is real. Account for the formula !
 
-                  if(!ruleFormula.accountMasses(isotopic_data_csp, oligomer))
+                  if(!ruleFormula.accountMasses(refList, oligomer))
                     return false;
-
-                  oligomer->m_formula.accountFormula(ruleFormula.toString(),
-                                                     isotopic_data_csp);
                 }
             }
         }
@@ -498,11 +490,11 @@ Cleaver::accountCleaveRule(libXpertMass::CleaveRule *cleaveRule,
         {
           // The formula has to be there.
 
-          libXpertMass::Formula ruleFormula = cleaveRule->rightFormula();
-          Q_ASSERT(!ruleFormula.toString().isEmpty());
+          Formula ruleFormula = cleaveRule->rightFormula();
+          Q_ASSERT(!ruleFormula.text().isEmpty());
 
           // What is the monomer at the right end of current oligomer ?
-          const libXpertMass::Monomer &monomer = oligomer->atRightEnd();
+          const Monomer &monomer = oligomer->atRightEnd();
 
           if(monomer.code() == cleaveRule->rightCode())
             {
@@ -520,11 +512,8 @@ Cleaver::accountCleaveRule(libXpertMass::CleaveRule *cleaveRule,
                   // The monomer is not the right-end monomer, so
                   // the match is real. Account for the formula !
 
-                  if(!ruleFormula.accountMasses(isotopic_data_csp, oligomer))
+                  if(!ruleFormula.accountMasses(refList, oligomer))
                     return false;
-
-                  oligomer->m_formula.accountFormula(ruleFormula.toString(),
-                                                     isotopic_data_csp);
                 }
             }
         }
@@ -548,16 +537,14 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   OligomerList partialOligomerList;
 
-  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
-    mcsp_polChemDef->getIsotopicDataCstSPtr();
+  // Since version 2.3.0, the cleavage might be performed on a
+  // selected portion of a sequence only, not necessarily on the
+  // whole polymer sequence. We have to know these values because
+  // when we create oligomer we'll have to set the coordinates of
+  // the monomers correctly.
 
-  // The cleavage might be performed on a selected portion of a sequence only,
-  // not necessarily on the whole polymer sequence. We have to know these values
-  // because when we create oligomer we'll have to set the coordinates of the
-  // monomers correctly.
-
-  libXpertMass::CoordinateList coordinateList = m_calcOptions.coordinateList();
-  libXpertMass::Coordinates *coordinates      = coordinateList.first();
+  CoordinateList coordinateList = m_calcOptions.coordinateList();
+  Coordinates *coordinates      = coordinateList.first();
 
   int startIndex = coordinates->start();
   int endIndex   = coordinates->end();
@@ -604,50 +591,26 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
       QString name = QString("%1#%2").arg(partialCleavageValue).arg(iter + 1);
 
-      CleaveOligomerSPtr oligomer_sp = std::make_shared<CleaveOligomer>(
+      CleaveOligomer *oligomer = new CleaveOligomer(
         mp_polymer,
         name,
         m_cleaveOptions.name(),
         mp_polymer->hasModifiedMonomer(leftIndex, rightIndex),
-        libXpertMass::Ponderable(),
+        Ponderable(),
         leftIndex,
         rightIndex,
         partialCleavageValue,
         m_calcOptions);
 
-      // The CleaveOligomer cannot compute its own elemental composition,
-      // contrary to libXpertMass::Oligomer.
+      partialOligomerList.append(oligomer);
 
-      // Use the shared pointer to the CleaveOligomer to access the base class
-      // function that works by using calcoptions to compute the formula of the
-      // oligomer.
-      QString elemental_composition =
-        oligomer_sp.get()->libXpertMass::Oligomer::elementalComposition();
-
-      // And now use that elemental composition to set it in the CleaveOligomer.
-
-      oligomer_sp->m_formula.accountFormula(
-        elemental_composition, isotopic_data_csp, 1);
-
-      // qDebug() << "Oligomer has formula:" <<
-      // oligomer_sp->elementalComposition();
-
-      // At this point we can add the configured oligomer to the list.
-      partialOligomerList.append(oligomer_sp);
-
-      // Increment the indx for next oligomer.
       leftIndex = m_cleaveIndexList.at(iter) + 1;
     }
   // End of
   // for (int iter = 0; iter < m_cleaveIndexList.size(); iter=+)
 
-  // At this point we have finished iterating in the cleave index list, but
-  // there was an oligomer cooking when we ended the looping. We should handle
-  // that stray oligomer exactly the same way we did for the other inside the
-  // loop.
-
-  // Indeed, this last oligomer that was cooking is the right-end oligomer ! And
-  // be sure to determine what's its real left end index !
+  // Do not forget the right-end oligomer ! And be sure to determine
+  // what's its real left end index !
 
   if(oligomerIsPolymer)
     leftIndex = startIndex;
@@ -660,50 +623,36 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   ++iter;
 
+  // Remove 1 because the oligomer is described using indices and not
+  // positions.
+
   rightIndex = endIndex;
 
   QString name = QString("%1#%2").arg(partialCleavageValue).arg(iter + 1);
 
-  CleaveOligomerSPtr oligomer_sp = std::make_shared<CleaveOligomer>(
-    mp_polymer,
-    name,
-    m_cleaveOptions.name(),
-    mp_polymer->hasModifiedMonomer(leftIndex, rightIndex),
-    libXpertMass::Ponderable(),
-    leftIndex,
-    rightIndex,
-    partialCleavageValue,
-    m_calcOptions);
+  CleaveOligomer *oligomer =
+    new CleaveOligomer(mp_polymer,
+                       name,
+                       m_cleaveOptions.name(),
+                       mp_polymer->hasModifiedMonomer(leftIndex, rightIndex),
+                       Ponderable(),
+                       leftIndex,
+                       rightIndex,
+                       partialCleavageValue,
+                       m_calcOptions);
 
-  // The CleaveOligomer cannot compute its own elemental composition,
-  // contrary to libXpertMass::Oligomer.
-
-  // Use the shared pointer to the CleaveOligomer to access the base class
-  // function that works by using calcoptions to compute the formula of the
-  // oligomer.
-  QString elemental_composition =
-    oligomer_sp.get()->libXpertMass::Oligomer::elementalComposition();
-
-  // And now use that elemental composition to set it in the CleaveOligomer.
-
-  oligomer_sp->m_formula.accountFormula(
-    elemental_composition, isotopic_data_csp, 1);
-
-  // qDebug() << "Oligomer has formula:" << oligomer_sp->elementalComposition();
-
-  // At this point we can add the configured oligomer to the list.
-  partialOligomerList.append(oligomer_sp);
+  partialOligomerList.append(oligomer);
 
   // At this point all the skeleton oligomers have been computed for
   // the given partialCleavageValue. We still have to perform the
   // cross-link analysis prior to both calculate the masses and
   // perform the ionization of all the generated oligomers. Note that
   // making cross-link analysis is only useful in case the cleavage is
-  // full (that is, partialCleavageValue == 0).
+  // full(partialCleavageValue == 0).
 
   if(!partialCleavageValue)
     {
-      if(m_calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_CROSS_LINK)
+      if(m_calcOptions.monomerEntities() & MONOMER_CHEMENT_CROSS_LINK)
         {
           if(analyzeCrossLinks(&partialOligomerList) == -1)
             {
@@ -725,10 +674,8 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   while(partialOligomerList.size())
     {
-      libXpertMass::OligomerSPtr iter_oligomer_sp = partialOligomerList.takeFirst();
-
-      CleaveOligomer *iter_oligomer_p =
-        dynamic_cast<CleaveOligomer *>(iter_oligomer_sp.get());
+      CleaveOligomer *iterOligomer =
+        static_cast<CleaveOligomer *>(partialOligomerList.takeFirst());
 
       // We do not ask that the oligomer be ionized yet, because we
       // have to first account for potential cleavage rules! Thus we
@@ -736,7 +683,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
       // iterOligomer->calculateMasses(*mp_calcOptions,
       // *mp_ionizeRule); This was a bug in the release versions up
       // to 1.6.1.
-      iter_oligomer_p->calculateMasses(&m_calcOptions);
+      iterOligomer->calculateMasses(&m_calcOptions);
 
       // At this point we should test if the oligomer has to be
       // processed using cleavage rules.
@@ -748,8 +695,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
           //  we have to ionize the oligomer only after we have
           //  completed the determination of its atomic composition.
 
-          libXpertMass::CleaveRule *cleaveRule =
-            m_cleaveOptions.ruleList()->at(jter);
+          CleaveRule *cleaveRule = m_cleaveOptions.ruleList()->at(jter);
 
           // qDebug() << __FILE__ << __LINE__
           //           << "Accounting for cleaverule:"
@@ -759,7 +705,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
           //           << "Oligomer mono mass before:" <<
           //           iterOligomer->mono();
 
-          if(!accountCleaveRule(cleaveRule, iter_oligomer_p))
+          if(!accountCleaveRule(cleaveRule, iterOligomer))
             return -1;
 
           // 	    qDebug() << __FILE__ << __LINE__
@@ -774,41 +720,36 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
       int startIonizeLevel = m_cleaveOptions.startIonizeLevel();
       int endIonizeLevel   = m_cleaveOptions.endIonizeLevel() + 1;
-      libXpertMass::IonizeRule ionizeRule(m_ionizeRule);
+      IonizeRule ionizeRule(m_ionizeRule);
 
       for(int kter = startIonizeLevel; kter < endIonizeLevel; ++kter)
         {
           ionizeRule.setLevel(kter);
 
-          CleaveOligomerSPtr new_oligomer_sp =
-            std::make_shared<CleaveOligomer>(*iter_oligomer_p);
+          CleaveOligomer *newOligomer = new CleaveOligomer(*iterOligomer);
 
-          if(new_oligomer_sp->ionize(ionizeRule) == -1)
-            return -1;
+          if(newOligomer->ionize(ionizeRule) == -1)
+            {
+              delete newOligomer;
 
-          new_oligomer_sp->m_formula.accountFormula(
-            ionizeRule.formula(), isotopic_data_csp, ionizeRule.level());
-
-          //qDebug() << "After ionization level" << kter
-                   //<< "with formula:" << ionizeRule.formula()
-                   //<< ", the new oligomer formula is:"
-                   //<< new_oligomer_sp->m_formula.toString();
+              return -1;
+            }
 
           // The name was set already during the creation of the
           // template oligomer. All we have to add to the name is the
           // ionization level.
 
-          QString name = iter_oligomer_p->name() +
-                         QString("#z=%3").arg(new_oligomer_sp->charge());
+          QString name =
+            iterOligomer->name() + QString("#z=%3").arg(newOligomer->charge());
 
-          new_oligomer_sp->setName(name);
+          newOligomer->setName(name);
 
-          waitOligomerList.append(new_oligomer_sp);
+          waitOligomerList.append(newOligomer);
         }
 
       // We can delete the template oligomer that was already removed
       // from the oligomerList(use of QList::takeFirst()).
-      iter_oligomer_sp.reset();
+      delete iterOligomer;
     }
 
   // At this point we should transfer all the oligomers from the
@@ -816,13 +757,9 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   while(waitOligomerList.size())
     {
-      // Crucial to make this pointer cast so that we transfer actual
-      // CleaveOligomers!
+      Oligomer *iterOligomer = waitOligomerList.takeFirst();
 
-      CleaveOligomerSPtr iter_oligomer_sp =
-        std::dynamic_pointer_cast<CleaveOligomer>(waitOligomerList.takeFirst());
-
-      partialOligomerList.append(iter_oligomer_sp);
+      partialOligomerList.append(iterOligomer);
     }
 
   // Finally transfer all the oligomers generated for this partial
@@ -834,20 +771,14 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   while(partialOligomerList.size())
     {
-      // Crucial to make this pointer cast so that we transfer actual
-      // CleaveOligomers!
+      Oligomer *iterOligomer = partialOligomerList.takeFirst();
 
-      CleaveOligomerSPtr iter_oligomer_sp =
-        std::dynamic_pointer_cast<CleaveOligomer>(
-          partialOligomerList.takeFirst());
+      // Elemental formula
+      QString *text    = new QString(iterOligomer->elementalComposition());
+      StringProp *prop = new StringProp("ELEMENTAL_COMPOSITION", text);
+      iterOligomer->appendProp(static_cast<Prop *>(prop));
 
-      //// Elemental formula
-      // QString *text = new QString(iter_oligomer_sp->elementalComposition());
-      // libXpertMass::StringProp *prop =
-      // new libXpertMass::StringProp("ELEMENTAL_COMPOSITION", text);
-      // iter_oligomer_sp->appendProp(static_cast<libXpertMass::Prop *>(prop));
-
-      mp_oligomerList->append(iter_oligomer_sp);
+      mp_oligomerList->append(iterOligomer);
     }
 
   return oligomerCount;
@@ -859,7 +790,7 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
 {
   Q_ASSERT(oligomerList);
 
-  OligomerList crossLinkedOligomerList;
+  QList<Oligomer *> crossLinkedOligomerList;
 
   // General overview:
 
@@ -869,16 +800,16 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
   // serve as a seed to pull-down all the oligomers cross-linked to
   // it.
 
-  const libXpertMass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
+  const CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
   for(int iter = 0; iter < crossLinkList.size(); ++iter)
     {
-      libXpertMass::CrossLink *crossLink = crossLinkList.at(iter);
+      CrossLink *crossLink = crossLinkList.at(iter);
 
       // With that crossLink, find an oligomer that encompasses the
       // first monomer of the cross-link.
 
-      const libXpertMass::Monomer *firstMonomer = crossLink->firstMonomer();
+      const Monomer *firstMonomer = crossLink->firstMonomer();
 
       Q_ASSERT(firstMonomer);
 
@@ -886,10 +817,10 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
 
       int foundIndex = 0;
 
-      libXpertMass::OligomerSPtr first_oligomer_sp =
+      Oligomer *firstOligomer =
         oligomerList->findOligomerEncompassing(firstMonomer, &foundIndex);
 
-      if(first_oligomer_sp)
+      if(firstOligomer)
         {
           // At this point we should turn this oligomer into a
           // cross-linked oligomer, so that we can continue performing its
@@ -903,10 +834,10 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
           oligomerList->removeAt(foundIndex);
 
           // Set the cross-linked oligomer apart.
-          crossLinkedOligomerList.append(first_oligomer_sp);
+          crossLinkedOligomerList.append(firstOligomer);
 
           // Finally deeply scrutinize the oligomer.
-          analyzeCrossLinkedOligomer(first_oligomer_sp, oligomerList);
+          analyzeCrossLinkedOligomer(firstOligomer, oligomerList);
         }
       else
         {
@@ -921,17 +852,17 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
   // for the partial cleavage. All we have to do is move all the
   // crossLinked oligomers from the crossLinkedOligomerList to
   // oligomerList. While doing so make sure that the m_calcOptions
-  // datum has correct libXpertMass::CoordinateList data, as these data will be
+  // datum has correct CoordinateList data, as these data will be
   // required later, typically to calculate the elemental formula of
   // the oligomer.
 
   while(crossLinkedOligomerList.size())
     {
-      libXpertMass::OligomerSPtr oligomer_sp = crossLinkedOligomerList.takeAt(0);
+      Oligomer *oligomer = crossLinkedOligomerList.takeAt(0);
 
-      oligomer_sp->updateCalcOptions();
+      oligomer->updateCalcOptions();
 
-      oligomerList->append(oligomer_sp);
+      oligomerList->append(oligomer);
     }
 
   crossLinkedOligomerList.clear();
@@ -944,32 +875,32 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
 
 
 int
-Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
+Cleaver::analyzeCrossLinkedOligomer(Oligomer *oligomer,
                                     OligomerList *oligomerList)
 {
-  Q_ASSERT(oligomer_sp);
+  Q_ASSERT(oligomer);
   Q_ASSERT(oligomerList);
 
-  const libXpertMass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
+  const CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
   OligomerList clearanceOligomerList;
 
-  // 'oligomer_sp' is the first oligomer in the cross-link series of
+  // 'oligomer' is the first oligomer in the cross-link series of
   // oligomers. It is the "seeding" oligomer with which to pull-down
   // all the others. Prepend to its name the "cl-" string to let it
   // know it is cross-linked.
 
-  QString name = oligomer_sp->name();
+  QString name = oligomer->name();
   name.prepend("cl-");
-  oligomer_sp->setName(name);
+  oligomer->setName(name);
 
-  // Iterate in the 'oligomer_sp' and for each monomer get any
+  // Iterate in the 'oligomer' and for each monomer get any
   // cross-linked oligomer out of the list of cross-links.
 
-  for(int iter = oligomer_sp->startIndex(); iter < oligomer_sp->endIndex() + 1;
+  for(int iter = oligomer->startIndex(); iter < oligomer->endIndex() + 1;
       ++iter)
     {
-      const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
+      const Monomer *monomer = mp_polymer->at(iter);
 
       // What crossLinks do involve this monomer ?
 
@@ -987,7 +918,7 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
 
           foreach(index, crossLinkIndices)
             {
-              libXpertMass::CrossLink *crossLink = crossLinkList.at(index);
+              CrossLink *crossLink = crossLinkList.at(index);
 
               // 	      qDebug() << __FILE__ << __LINE__
               // 			<< crossLink->name();
@@ -1001,7 +932,7 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
               // call below first checks that the cross-link is not
               // already in the list).
 
-              if(!oligomer_sp->addCrossLink(crossLink))
+              if(!oligomer->addCrossLink(crossLink))
                 {
                   //  qDebug() << __FILE__ << __LINE__
                   //	    << "The cross-link:"
@@ -1021,7 +952,7 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
                   //	    << "oligomer's list of cross-links.";
                 }
 
-              const libXpertMass::Monomer *iterMonomer = 0;
+              const Monomer *iterMonomer = 0;
 
               foreach(iterMonomer, *(crossLink->monomerList()))
                 {
@@ -1030,11 +961,11 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
 
                   int foundIndex = 0;
 
-                  libXpertMass::OligomerSPtr found_oligomer_sp =
+                  Oligomer *foundOligomer =
                     oligomerList->findOligomerEncompassing(iterMonomer,
                                                            &foundIndex);
 
-                  if(found_oligomer_sp)
+                  if(foundOligomer)
                     {
                       // qDebug() << __FILE__ << __LINE__
                       // 	<< foundOligomer->name() << foundIndex;
@@ -1049,15 +980,15 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
 
                       oligomerList->removeAt(foundIndex);
 
-                      clearanceOligomerList.append(found_oligomer_sp);
+                      clearanceOligomerList.append(foundOligomer);
 
                       // Update the name of the oligomer with the name
                       // of the new foundOligomer.
 
                       QString name = QString("%1+%2")
-                                       .arg(oligomer_sp->name())
-                                       .arg(found_oligomer_sp->name());
-                      oligomer_sp->setName(name);
+                                       .arg(oligomer->name())
+                                       .arg(foundOligomer->name());
+                      oligomer->setName(name);
                     }
                 }
             }
@@ -1081,13 +1012,13 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
 
   while(clearanceOligomerList.size())
     {
-      libXpertMass::OligomerSPtr iter_oligomer_sp = clearanceOligomerList.first();
+      Oligomer *iterOligomer = clearanceOligomerList.first();
 
-      for(int iter = iter_oligomer_sp->startIndex();
-          iter < iter_oligomer_sp->endIndex() + 1;
+      for(int iter = iterOligomer->startIndex();
+          iter < iterOligomer->endIndex() + 1;
           ++iter)
         {
-          const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
+          const Monomer *monomer = mp_polymer->at(iter);
 
           // 	  qDebug() << __FILE__ << __LINE__
           // 		    << monomer->name();
@@ -1102,13 +1033,13 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
           if(ret)
             {
               // At least one cross-link involves the monomer currently
-              // iterated in the iter_oligomer_sp being analysed.
+              // iterated in the iterOligomer being analysed.
 
               int index = 0;
 
               foreach(index, crossLinkIndices)
                 {
-                  libXpertMass::CrossLink *crossLink = crossLinkList.at(index);
+                  CrossLink *crossLink = crossLinkList.at(index);
 
                   // 		  qDebug() << __FILE__ << __LINE__
                   // 			    << crossLink->name();
@@ -1122,7 +1053,7 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
                   // call below first checks that the cross-link is not
                   // already in the list).
 
-                  if(!oligomer_sp->addCrossLink(crossLink))
+                  if(!oligomer->addCrossLink(crossLink))
                     {
                       // qDebug() << __FILE__ << __LINE__
                       // << "The cross-link:"
@@ -1142,7 +1073,7 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
                       // << "oligomer's list of cross-links.";
                     }
 
-                  const libXpertMass::Monomer *iterMonomer = 0;
+                  const Monomer *iterMonomer = 0;
 
                   foreach(iterMonomer, *(crossLink->monomerList()))
                     {
@@ -1151,11 +1082,11 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
 
                       int foundIndex = 0;
 
-                      libXpertMass::OligomerSPtr found_oligomer_sp =
+                      Oligomer *foundOligomer =
                         oligomerList->findOligomerEncompassing(iterMonomer,
                                                                &foundIndex);
 
-                      if(found_oligomer_sp)
+                      if(foundOligomer)
                         {
                           // qDebug() << __FILE__ << __LINE__
                           //          << foundOligomer->name() << foundIndex;
@@ -1170,15 +1101,15 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
 
                           oligomerList->removeAt(foundIndex);
 
-                          clearanceOligomerList.append(found_oligomer_sp);
+                          clearanceOligomerList.append(foundOligomer);
 
                           // Update the name of the oligomer with the name
                           // of the new foundOligomer.
 
                           QString name = QString("%1+%2")
-                                           .arg(oligomer_sp->name())
-                                           .arg(found_oligomer_sp->name());
-                          oligomer_sp->setName(name);
+                                           .arg(oligomer->name())
+                                           .arg(foundOligomer->name());
+                          oligomer->setName(name);
                         }
                     }
                 }
@@ -1188,8 +1119,8 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
           // End of(ret) ie cross-links involved monomer
         }
       // End of
-      //   for (int iter = iter_oligomer_sp->startIndex();
-      //   iter < iter_oligomer_sp->endIndex() + 1; ++iter)
+      //   for (int iter = iterOligomer->startIndex();
+      //   iter < iterOligomer->endIndex() + 1; ++iter)
 
       // At this point this quarantinized oligomer might be removed
       // from the clearance clearanceOligomerList and its coordinates
@@ -1198,9 +1129,9 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
 
       clearanceOligomerList.removeFirst();
 
-      oligomer_sp->appendCoordinates(iter_oligomer_sp.get());
+      oligomer->appendCoordinates(iterOligomer);
 
-      iter_oligomer_sp.reset();
+      delete iterOligomer;
     }
 
   // At this point, all the oligomers in the clearance oligomer list
@@ -1213,17 +1144,19 @@ Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
   //       oligomer->crossLinkList()->at(iter)->name();
 
 
-  return static_cast<libXpertMass::CoordinateList *>(oligomer_sp.get())->size();
+  return static_cast<CoordinateList *>(oligomer)->size();
 }
 
 
 void
 Cleaver::emptyOligomerList()
 {
-  if(mp_oligomerList != nullptr)
-    mp_oligomerList->clear();
+  while(mp_oligomerList->size())
+    {
+      delete mp_oligomerList->takeFirst();
+    }
 }
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
