@@ -37,10 +37,11 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/CrossLink.hpp>
+#include "CrossLink.hpp"
+#include "CrossLinkList.hpp"
 
 
-namespace MsXpS {
+namespace msxps {
 
 
 	namespace massxpert
@@ -56,7 +57,7 @@ class CrossLinkedRegion
   // We do not own the cross-links, we cannot destroy them because
   // that would destroy the cross-links in the polymer sequence,
   // which we do not want!!
-  QList<libXpertMass::CrossLink *> m_crossLinkList;
+  QList<CrossLink *> m_crossLinkList;
 
 
   public:
@@ -72,18 +73,18 @@ class CrossLinkedRegion
   void setEndIndex(int);
   int endIndex();
 
-  const QList<libXpertMass::CrossLink *> &crossLinkList() const;
+  const QList<CrossLink *> &crossLinkList() const;
 
-  int appendCrossLink(libXpertMass::CrossLink *);
-  int appendCrossLinks(const QList<libXpertMass::CrossLink *> &);
+  int appendCrossLink(CrossLink *);
+  int appendCrossLinks(const QList<CrossLink *> &);
 
-  int removeCrossLink(libXpertMass::CrossLink *);
+  int removeCrossLink(CrossLink *);
   int removeCrossLinkAt(int);
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // CROSS_LINKED_REGION_HPP
