@@ -446,7 +446,7 @@ Formula::actions() const
   double quotes, that is located in front of the actual chemical
   actionformula.  This function removes that <em>title</em> element from the
   \c m_formula actionformula. The \e title substring of the actionformula is
-  removed using a QRegExp.
+  removed using a QRegularExpression.
 
   \return the number of removed characters.
 
@@ -456,7 +456,7 @@ Formula::removeTitle()
 {
   int length = m_formula.length();
 
-  m_formula.remove(QRegExp("\".*\""));
+  m_formula.remove(QRegularExpression("\".*\""));
 
   return (length - m_formula.length());
 }
@@ -467,7 +467,7 @@ Formula::removeTitle()
 
   Spaces can be placed anywhere in formula for more readability. However, it
   might be required that these character spaces be removed. This function does
-  just this, using a QRegExp.
+  just this, using a QRegularExpression.
 
   \return the number of removed characters.
 
@@ -479,7 +479,7 @@ Formula::removeSpaces()
 
   // We want to remove all the possibly-existing spaces.
 
-  m_formula.remove(QRegExp("\\s+"));
+  m_formula.remove(QRegularExpression("\\s+"));
 
   // Return the number of removed characters.
   return (length - m_formula.length());
@@ -565,11 +565,11 @@ Formula::splitParts(const QList<Atom *> &refList,
   // The "Decomposed adenine" is the title
   // The C5H4N5 +H is the formula.
 
-  formula.remove(QRegExp("\".*\""));
+  formula.remove(QRegularExpression("\".*\""));
 
   // We want to remove all the possibly-existing spaces.
 
-  formula.remove(QRegExp("\\s+"));
+  formula.remove(QRegularExpression("\\s+"));
 
   // If the formula does not contain any '-' character, then we
   // can approximate that all the formula is a '+' formula, that is a
@@ -1171,11 +1171,11 @@ Formula::checkSyntax(const QString &formula, bool forceCountIndex)
   // The "Decomposed adenine" is the title
   // The C5H4N5 +H is the formula.
 
-  localFormula.remove(QRegExp("\".*\""));
+  localFormula.remove(QRegularExpression("\".*\""));
 
   // We want to remove all the possibly-existing spaces.
 
-  localFormula.remove(QRegExp("\\s+"));
+  localFormula.remove(QRegularExpression("\\s+"));
 
 
   for(int iter = 0; iter < localFormula.length(); ++iter)
@@ -1595,7 +1595,7 @@ Formula::elementalComposition(
   QString positiveComponentString;
 
   // Carbon
-  atomIndex = positiveStringList.indexOf(QRegExp("C\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("C\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1607,7 +1607,7 @@ Formula::elementalComposition(
     }
 
   // Hydrogen
-  atomIndex = positiveStringList.indexOf(QRegExp("H\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("H\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1619,7 +1619,7 @@ Formula::elementalComposition(
     }
 
   // Nitrogen
-  atomIndex = positiveStringList.indexOf(QRegExp("N\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("N\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1631,7 +1631,7 @@ Formula::elementalComposition(
     }
 
   // Oxygen
-  atomIndex = positiveStringList.indexOf(QRegExp("O\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("O\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1643,7 +1643,7 @@ Formula::elementalComposition(
     }
 
   // Sulfur
-  atomIndex = positiveStringList.indexOf(QRegExp("S\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("S\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1655,7 +1655,7 @@ Formula::elementalComposition(
     }
 
   // Phosphorus
-  atomIndex = positiveStringList.indexOf(QRegExp("P\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("P\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1708,7 +1708,7 @@ Formula::elementalComposition(
   QString negativeComponentString;
 
   // Carbon
-  atomIndex = negativeStringList.indexOf(QRegExp("C\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("C\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1720,7 +1720,7 @@ Formula::elementalComposition(
     }
 
   // Hydrogen
-  atomIndex = negativeStringList.indexOf(QRegExp("H\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("H\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1732,7 +1732,7 @@ Formula::elementalComposition(
     }
 
   // Nitrogen
-  atomIndex = negativeStringList.indexOf(QRegExp("N\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("N\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1744,7 +1744,7 @@ Formula::elementalComposition(
     }
 
   // Oxygen
-  atomIndex = negativeStringList.indexOf(QRegExp("O\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("O\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1756,7 +1756,7 @@ Formula::elementalComposition(
     }
 
   // Sulfur
-  atomIndex = negativeStringList.indexOf(QRegExp("S\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("S\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1768,7 +1768,7 @@ Formula::elementalComposition(
     }
 
   // Phosphorus
-  atomIndex = negativeStringList.indexOf(QRegExp("P\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("P\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
