@@ -33,23 +33,23 @@
 
 /////////////////////// Local includes
 #include "FragOptions.hpp"
-#include <libXpertMass/PolChemDef.hpp>
-#include <libXpertMass/PolChemDefEntity.hpp>
+#include "PolChemDef.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-FragOptions::FragOptions(libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
+
+FragOptions::FragOptions(PolChemDef *polChemDef,
                          QString name,
                          QString formula,
-                         libXpertMass::FragEnd fragEnd,
+                         MxtFragEnd fragEnd,
                          const QString &comment,
                          bool sequenceEmbedded)
-  : libXpertMass::FragSpec(polChemDefCstSPtr, name, formula, fragEnd, comment),
+  : FragSpec(polChemDef, name, formula, fragEnd, comment),
     m_sequenceEmbedded(sequenceEmbedded)
 {
   // Have to be 1 and not 0, otherwise the setting functions ensuring
@@ -59,11 +59,11 @@ FragOptions::FragOptions(libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
 }
 
 
-FragOptions::FragOptions(const libXpertMass::FragSpec &fragSpec,
+FragOptions::FragOptions(const FragSpec &fragSpec,
                          int startIndex,
                          int endIndex,
                          bool sequenceEmbedded)
-  : libXpertMass::FragSpec(fragSpec),
+  : FragSpec(fragSpec),
     m_startIndex(startIndex),
     m_endIndex(endIndex),
     m_sequenceEmbedded(sequenceEmbedded)
@@ -76,7 +76,7 @@ FragOptions::FragOptions(const libXpertMass::FragSpec &fragSpec,
 
 
 FragOptions::FragOptions(const FragOptions &other)
-  : libXpertMass::FragSpec(other),
+  : FragSpec(other),
     m_startIndex(other.m_startIndex),
     m_endIndex(other.m_endIndex),
     m_startIonizeLevel(other.m_startIonizeLevel),
@@ -85,8 +85,7 @@ FragOptions::FragOptions(const FragOptions &other)
 {
   for(int iter = 0; iter < other.m_formulaList.size(); ++iter)
     {
-      libXpertMass::Formula *formula =
-        new libXpertMass::Formula(*other.m_formulaList.at(iter));
+      Formula *formula = new Formula(*other.m_formulaList.at(iter));
       m_formulaList.append(formula);
     }
 }
@@ -94,7 +93,7 @@ FragOptions::FragOptions(const FragOptions &other)
 
 FragOptions::~FragOptions()
 {
-  // There might be some allocated libXpertMass::Formula instances in the
+  // There might be some allocated Formula instances in the
   // m_formulaList. Free them.
 
   while(!m_formulaList.isEmpty())
@@ -102,30 +101,35 @@ FragOptions::~FragOptions()
 }
 
 
-FragOptions &
-FragOptions::operator=(const FragOptions &other)
+FragOptions *
+FragOptions::clone() const
+{
+  FragOptions *other = new FragOptions(*this);
+
+  return other;
+}
+
+
+void
+FragOptions::clone(FragOptions *other) const
+{
+  Q_ASSERT(other);
+
+  FragSpec::clone(other);
+
+  other->m_sequenceEmbedded = m_sequenceEmbedded;
+}
+
+
+void
+FragOptions::mold(const FragOptions &other)
 {
   if(&other == this)
-    return *this;
+    return;
 
-  libXpertMass::FragSpec::operator=(other);
-
-  m_startIndex = other.m_startIndex;
-  m_endIndex   = other.m_endIndex;
-
-  m_startIonizeLevel = other.m_startIonizeLevel;
-  m_endIonizeLevel   = other.m_endIonizeLevel;
+  FragSpec::mold(other);
 
   m_sequenceEmbedded = other.m_sequenceEmbedded;
-
-  for(int iter = 0; iter < other.m_formulaList.size(); ++iter)
-    {
-      libXpertMass::Formula *formula =
-        new libXpertMass::Formula(*other.m_formulaList.at(iter));
-      m_formulaList.append(formula);
-    }
-
-  return *this;
 }
 
 
@@ -205,7 +209,7 @@ FragOptions::endIonizeLevel() const
 }
 
 bool
-FragOptions::addFormula(const libXpertMass::Formula &formula)
+FragOptions::addFormula(const Formula &formula)
 {
   // First check that the formula is not already in the list.
 
@@ -218,16 +222,14 @@ FragOptions::addFormula(const libXpertMass::Formula &formula)
   // At this point we can say that the formula is OK and can be
   // added.
 
-  libXpertMass::Formula *newFormula = new libXpertMass::Formula(formula);
+  Formula *newFormula = new Formula(formula);
 
   // At this point, we should check if the formula is valid.
+  const QList<Atom *> &atomRefList = mp_polChemDef->atomList();
 
-  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
-    mcsp_polChemDef->getIsotopicDataCstSPtr();
-
-  if(!newFormula->validate(isotopic_data_csp))
+  if(!newFormula->validate(atomRefList))
     {
-      qDebug() << "Formula" << newFormula->toString() << "failed to validate.";
+      qDebug() << "Formula" << newFormula->text() << "failed to validate.";
 
       delete newFormula;
 
@@ -242,15 +244,15 @@ FragOptions::addFormula(const libXpertMass::Formula &formula)
 bool
 FragOptions::addFormula(const QString &text)
 {
-  // With the string make a true libXpertMass::Formula instance.
+  // With the string make a true Formula instance.
 
-  libXpertMass::Formula formula = libXpertMass::Formula(text);
+  Formula formula = Formula(text);
 
   return addFormula(formula);
 }
 
 
-const QList<libXpertMass::Formula *> &
+const QList<Formula *> &
 FragOptions::formulaList()
 {
   return m_formulaList;
@@ -269,37 +271,6 @@ FragOptions::isSequenceEmbedded() const
   return m_sequenceEmbedded;
 }
 
-
-QString
-FragOptions::toString() const
-{
-  QString text = "Fragoptions: ";
-
-  text += QString("indices [%1-%2] -- ionization levels [%3-%4].\n")
-            .arg(m_startIndex)
-            .arg(m_endIndex)
-            .arg(m_startIonizeLevel)
-            .arg(m_endIonizeLevel);
-
-  if(m_formulaList.size())
-    {
-      text += "Formulas:\n";
-
-      QList<libXpertMass::Formula *>::const_iterator iter = m_formulaList.cbegin();
-      QList<libXpertMass::Formula *>::const_iterator iter_end = m_formulaList.cend();
-
-      while(iter != iter_end)
-        {
-          text += QString("%1 - ").arg((*iter)->toString());
-          ++iter;
-        }
-
-      text += "\n";
-    }
-
-  return text;
-}
-
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
