@@ -1953,7 +1953,7 @@ Fragmenter::accountIonizationLevels(OligomerList *oligomerList,
           QString name        = newOligomer->name();
           QString chargeLevel = QString("z=%1").arg(newOligomer->charge());
 
-          name.replace(QRegExp("z=\\d+$"), chargeLevel);
+          name.replace(QRegularExpression("z=\\d+$"), chargeLevel);
 
           newOligomer->setName(name);
 
