@@ -221,7 +221,7 @@ namespace massxpert
     stringList.clear();
 
     stringList =
-      m_targets.split(';', QString::SkipEmptyParts, Qt::CaseSensitive);
+      m_targets.split(';', Qt::SkipEmptyParts, Qt::CaseSensitive);
     return stringList.size();
   }
 
@@ -265,7 +265,7 @@ namespace massxpert
 
     // A targets string looks like "Ser ; Thr ; Tyr".
     QStringList stringList =
-      m_targets.split(';', QString::SkipEmptyParts, Qt::CaseSensitive);
+      m_targets.split(';', Qt::SkipEmptyParts, Qt::CaseSensitive);
 
     for(int iter = 0; iter < stringList.size(); ++iter)
       {
