@@ -31,38 +31,44 @@
  */
 
 
-#pragma once
+#ifndef OLIGOMER_PAIR_HPP
+#define OLIGOMER_PAIR_HPP
+
 
 /////////////////////// Qt includes
 #include <QString>
 
 
 /////////////////////// Local includes
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/PropListHolder.hpp>
-#include <libXpertMass/Oligomer.hpp>
+#include "../nongui/globals.hpp"
+#include "PropListHolder.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-class OligomerPair : public libXpertMass::PropListHolder
+
+
+class Oligomer;
+
+
+class OligomerPair : public PropListHolder
 {
   protected:
-  const libXpertMass::OligomerSPtr msp_oligomer1;
-  const libXpertMass::OligomerSPtr msp_oligomer2;
-  libXpertMass::MassType m_massType;
+  const Oligomer *mp_oligomer1;
+  const Oligomer *mp_oligomer2;
+  MassType m_massType;
   double m_error;
   bool m_isMatching;
   QString m_name;
 
   public:
-  OligomerPair(const libXpertMass::OligomerSPtr,
-               const libXpertMass::OligomerSPtr,
-               libXpertMass::MassType,
+  OligomerPair(const Oligomer *,
+               const Oligomer *,
+               MassType,
                double          = 0,
                bool isMatching = false,
                const QString & = QString());
@@ -73,11 +79,11 @@ class OligomerPair : public libXpertMass::PropListHolder
 
   QString name();
 
-  const libXpertMass::OligomerSPtr oligomer1() const;
-  const libXpertMass::OligomerSPtr oligomer2() const;
+  const Oligomer *oligomer1() const;
+  const Oligomer *oligomer2() const;
 
-  void setMassType(libXpertMass::MassType);
-  libXpertMass::MassType massType() const;
+  void setMassType(MassType);
+  MassType massType() const;
 
   void setError(double);
   double error() const;
@@ -92,11 +98,9 @@ class OligomerPair : public libXpertMass::PropListHolder
   int charge2();
 };
 
-typedef std::shared_ptr<OligomerPair> OligomerPairSPtr;
-typedef std::shared_ptr<const OligomerPair> OligomerPairCstSPtr;
-
-
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
+
+#endif // OLIGOMER_PAIR_HPP
