@@ -1312,7 +1312,7 @@ PolChemDef::writeXmlFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   // The DTD
   string = formatXmlDtd();
