@@ -1900,7 +1900,7 @@ Polymer::writeXmlFile()
     }
 
   QTextStream stream(&file);
-  stream.setCodec("UTF-8");
+  stream.setEncoding(QStringConverter::Utf8);
 
   // The DTD
   string = formatXmlDtd();
