@@ -30,6 +30,7 @@
  * END software license
  */
 
+#include <QByteArrayView>
 
 /////////////////////// Local includes
 #include "Sequence.hpp"
@@ -820,7 +821,7 @@ Sequence::checksum(int startIdx, int endIdx, bool withModifs) const
 
   QByteArray bytes = text->toUtf8();
 
-  quint16 checksum = qChecksum(bytes.data(), bytes.size());
+  quint16 checksum = qChecksum(QByteArrayView(bytes));
 
   //     qDebug() << __FILE__ << __LINE__
   // 	     << "checksum:" << checksum;
